<?php
// modules/MultiParagraph.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class MultiParagraph {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('multiParagraph_');
        $this->settings = array_merge([
            'buttonName' => 'Multi Paragraph',
            'headerText' => 'NOW, TAKE TIME TO REFLECT',
            'rows' => [
                [
                    'label' => 'My greatest vulnerability is:',
                    'example' => '(Examples include: lust, anger, jealousy, pride, greed)'
                ],
                [
                    'label' => 'The primary source of spiritual attack against me has been through:',
                    'example' => '(Examples: my family, my employer, my neighbors)'
                ],
                [
                    'label' => 'A fresh, redemptive approach for me to take would be:',
                    'example' => '(Examples: quote scripture as Jesus did, identify the Christ-like character trait that would neutralize this attack, pray for the circumstance)'
                ]
            ]
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        
        <div class="module-preview multi-paragraph-module"
             data-module="MultiParagraph"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <style>
                .multi-paragraph-container {
                    max-width: 1100px;
                    margin: 0 auto;
                    font-family: Arial, sans-serif;
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    overflow: hidden;
                    background: #fff;
                }
                .multi-paragraph-header {
                    background: #074a77;
                    color: #fff;
                    font-weight: bold;
                    text-align: center;
                    font-size: 18px;
                    padding: 15px;
                }
                table.multi-paragraph-table {
                    width: 100%;
                    border-collapse: collapse;
                    table-layout: fixed;  /* Ensures equal width */
                }
                table.multi-paragraph-table td {
                    border: 1px solid #ccc;
                    padding: 15px;
                    vertical-align: top;
                    width: 50%;  /* Forces each side to take 50% */
                }
                .label-bold {
                    font-weight: bold;
                    color: #074a77;
                    margin-bottom: 5px;
                    display: block;
                }
                textarea {
                    width: 100%;
                    height: 100px;
                    border: 1px solid #999;
                    border-radius: 8px;
                    padding: 10px;
                    resize: vertical;
                    font-size: 14px;
                    font-family: Arial, sans-serif;
                    box-sizing: border-box;
                }
            </style>

            <div class="multi-paragraph-container">
                <div class="multi-paragraph-header"><?php echo esc($this->settings['headerText']); ?></div>

                <table class="multi-paragraph-table">
                    <?php foreach ($this->settings['rows'] as $row): ?>
                    <tr>
                        <td>
                            <span class="label-bold"><?php echo esc($row['label']); ?></span>
                            <div style="color:#074a77;"><?php echo esc($row['example']); ?></div>
                        </td>
                        <td>
                            <textarea></textarea>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </table>
            </div>
        </div>

        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="MultiParagraph">'
             . esc($this->settings['buttonName']) . '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="headerText">Header Text:</label>
            <input type="text" id="headerText" data-update="headerText"
                   value="<?php echo esc($this->settings['headerText']); ?>">
        </div>
        <!-- Future: Add dynamic control to edit each row -->
        <small>Editing rows will be added in the next phase.</small>
        <?php
        return ob_get_clean();
    }
}
?>
