<?php
// modules/ScriptureModule.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ScriptureModule {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('scripture_');
        $this->settings = array_merge([
            'buttonName'    => 'Scripture',
            'scriptureText' => '“For if you forgive men their trespasses, your heavenly Father will also forgive you.”',
            'referenceText' => 'Matthew 6:14',
            'fontSize'      => '20px',
            'textAlign'     => 'center',
            'color'         => '#005484'
        ], $settings);
    }

    // Render the scripture module
    public function render() {
        ob_start(); ?>
        <div class="module-preview scripture-module"
             data-module="ScriptureModule"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             style="text-align: <?php echo esc($this->settings['textAlign']); ?>;
                    font-family: 'Open Sans', sans-serif;
                    font-size: <?php echo esc($this->settings['fontSize']); ?>;
                    color: <?php echo esc($this->settings['color']); ?>;">
            
            <!-- Scripture Text -->
            <p style="font-style: italic; margin-bottom: 10px;">
                <?php echo esc($this->settings['scriptureText']); ?>
            </p>

            <!-- Reference -->
            <p style="font-weight: 600; font-family: 'Open Sans', sans-serif;">
                <?php echo esc($this->settings['referenceText']); ?>
            </p>
        </div>
        <?php
        return ob_get_clean();
    }

    // Sidebar button
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ScriptureModule">' 
             . esc($this->settings['buttonName']) . 
             '</button>';
    }

    // Optional settings (expand later if needed)
    public function renderSettings() {
        ob_start(); ?>
        <!-- Add settings form here if needed -->
        <?php
        return ob_get_clean();
    }
}
?>
