<?php

namespace Config;

use CodeIgniter\Config\AutoloadConfig;

/**
 * -------------------------------------------------------------------
 * AUTOLOADER CONFIGURATION
 * -------------------------------------------------------------------
 *
 * This file defines the namespaces and class maps so the Autoloader
 * can find the files as needed.
 *
 * NOTE: If you use an identical key in $psr4 or $classmap, then
 *       the values in this file will overwrite the framework's values.
 *
 * NOTE: This class is required prior to Autoloader instantiation,
 *       and does not extend BaseConfig.
 *
 * @immutable
 */
class Autoload extends AutoloadConfig
{
    /**
     * -------------------------------------------------------------------
     * Namespaces (Class Auto-loading)
     * -------------------------------------------------------------------
     * This maps the locations of any namespaces in your application to
     * their location on the file system.
     *
     * @var array<string, list<string>|string>
     */
    public $psr4 = [
        APP_NAMESPACE                  => APPPATH, // Default App namespace
        'Config'                       => APPPATH . 'Config',
        'Modules'                      => APPPATH . 'Modules/',  // Register Modules directory
        'App\\Modules\\AppMaker'       => APPPATH . 'Modules/AppMaker/', // Register the AppMaker module
    ];

    /**
     * -------------------------------------------------------------------
     * View Namespace Auto-loading
     * -------------------------------------------------------------------
     *
     * While CodeIgniter doesn't autoload views in the same way as classes,
     * you can make sure the `view()` function works correctly with the proper path.
     *
     * The view path for AppMaker module should be added to CodeIgniter's view mechanism.
     */
    public $viewPaths = [
        APPPATH . 'Modules/AppMaker/Views',  // Add this path to be recognized by CodeIgniter's view mechanism
    ];

    /**
     * -------------------------------------------------------------------
     * Class Map
     * -------------------------------------------------------------------
     * Classes mapped to exact file locations.
     *
     * @var array<string, string>
     */
    public $classmap = [];

    /**
     * -------------------------------------------------------------------
     * Files to Autoload
     * -------------------------------------------------------------------
     * Useful for loading custom functions.
     *
     * @var list<string>
     */
    public $files = [];

    /**
     * -------------------------------------------------------------------
     * Helpers to Autoload
     * -------------------------------------------------------------------
     * Example:
     * public $helpers = ['url', 'form'];
     *
     * @var list<string>
     */
    public $helpers = [];
}
