<?php

use CodeIgniter\Router\RouteCollection;

// Enable CORS headers for all requests
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");

/**
 * @var RouteCollection $routes
 */

// Home Route
$routes->get('/', 'Home::index');

// ✅ AppMaker Module Group (Primary access via /app-maker/)
$routes->group('app-maker', ['namespace' => 'App\Modules\AppMaker\Controllers'], function($routes) {
    $routes->get('/', 'AppMaker::index');            // https://main.winslowapps.com/app-maker/
    $routes->get('db-test', 'DbTest::index');        // https://main.winslowapps.com/app-maker/db-test
});

// ✅ Friendly URLs pointing to AppMaker::index()
$routes->get('create-app', '\App\Modules\AppMaker\Controllers\AppMaker::index'); // https://main.winslowapps.com/create-app
$routes->get('builder', '\App\Modules\AppMaker\Controllers\AppMaker::index');     // https://main.winslowapps.com/builder

// ✅ Email Test
$routes->get('email-test', 'EmailTest::index');

// ✅ Registration Routes
$routes->group('auth', function ($routes) {
    $routes->get('register', 'Auth::register');
    $routes->post('processRegister', 'Auth::processRegister');
    $routes->get('login', 'Auth::login');
    $routes->post('processLogin', 'Auth::processLogin');
    $routes->get('auth/verifyEmail/(:any)', 'Auth::verifyEmail/$1');
    $routes->get('forgotPassword', 'Auth::forgotPassword');
    $routes->post('forgotPassword', 'Auth::processForgotPassword');
    $routes->get('resetPassword/(:any)', 'Auth::resetPassword/$1');
    $routes->post('processResetPassword/(:any)', 'Auth::processResetPassword/$1');
});

// ✅ Registration Success Page
$routes->get('register-success', 'Auth::registerSuccess');

// ✅ User Management
$routes->group('users', function ($routes) {
    $routes->get('edit/(:num)', 'Auth::editUser/$1');
    $routes->post('update/(:num)', 'Auth::updateUser/$1');
});

// ✅ Profile Management
$routes->group('profile', function ($routes) {
    $routes->get('edit', 'Auth::editProfile');
    $routes->post('update', 'Auth::updateProfile');
});

// ✅ Dashboard
$routes->get('dashboard', 'DashboardController::index');

// ✅ Log Out
$routes->get('logout', 'Auth::logout');

// ✅ Form Builder
$routes->get('form-builder', 'FormBuilder::index');
$routes->get('form-builder-dev', 'FormBuilder::dev');

// ✅ App Builder Routes
$routes->get('app-builder/testInsert', 'AppBuilder::testInsert');
$routes->get('app-builder', 'AppBuilder::index');
$routes->post('save_app', 'AppBuilder::saveApp');




// ✅ Dynamic Module File Loader
$routes->get('modules/(:any)', function ($moduleFile) {
    $filePath = APPPATH . 'Views/modules/' . $moduleFile;
    if (!file_exists($filePath)) {
        throw \CodeIgniter\Exceptions\PageNotFoundException::forPageNotFound();
    }
    return view('modules/' . $moduleFile);
});

// ✅ Module Preview Route
$routes->get('module-preview/(:any)', 'ModulePreview::show/$1');

// ✅ Dynamic App Path
$routes->get('apps/(:segment)', 'AppBuilder::loadApp/$1');

// ✅ File Upload Route
$routes->post('upload_logo', 'UploadController::uploadLogo');
$routes->get('upload', 'UploadController::index');
$routes->post('upload/upload', 'UploadController::upload');
$routes->get('upload/getImages', 'UploadController::getImages');

$routes->get('test-upload', 'UploadController::index');


// ✅ Test Autoload Route
$routes->get('autoloadtest', 'AutoloadTest::index');


$routes->post('update-module', 'AppBuilder::update_module');
$routes->post('app-builder/update_module', 'AppBuilder::update_module'); 

// Version 2 Routes
$routes->get('ws-app-maker', '\App\Controllers\WSAppMaker::index');

$routes->get('check-routes', 'RouteChecker::index');

