<?php

namespace App\Controllers;

use CodeIgniter\HTTP\ResponseInterface;

class ImageUploadController extends BaseController
{
    // ✅ Upload Image Endpoint
    public function upload()
    {
        $file = $this->request->getFile('file');

        if (!$file || !$file->isValid()) {
            return $this->response->setJSON([
                'success' => false,
                'message' => 'No valid file uploaded.'
            ]);
        }

        // Validate file type
        $validTypes = ['image/jpeg', 'image/png', 'image/gif', 'image/webp'];
        if (!in_array($file->getMimeType(), $validTypes)) {
            return $this->response->setJSON([
                'success' => false,
                'message' => 'Invalid file type. Only images allowed.'
            ]);
        }

        // Move the file
        $uploadPath = FCPATH . 'uploads/';
        if (!is_dir($uploadPath)) {
            mkdir($uploadPath, 0755, true);
        }

        $newName = $file->getRandomName();
        if ($file->move($uploadPath, $newName)) {
            return $this->response->setJSON([
                'success' => true,
                'filePath' => base_url('uploads/' . $newName),
                'fileName' => $newName
            ]);
        }

        return $this->response->setJSON([
            'success' => false,
            'message' => 'Failed to move uploaded file.'
        ]);
    }

    // ✅ List Existing Uploaded Images
    public function list()
    {
        $uploadPath = FCPATH . 'uploads/';
        $files = [];

        if (is_dir($uploadPath)) {
            $dir = opendir($uploadPath);
            while (($file = readdir($dir)) !== false) {
                if ($file === '.' || $file === '..') continue;
                $filePath = base_url('uploads/' . $file);
                $files[] = [
                    'name' => $file,
                    'url' => $filePath
                ];
            }
            closedir($dir);
        }

        return $this->response->setJSON([
            'success' => true,
            'files' => $files
        ]);
    }
}
