<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PageTextModule {
    private $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageText_');
        $this->settings = array_merge([
            'content'       => 'Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text.',
            'fontSize'      => '20px',
            'fontWeight'    => 'bold',
            'textAlign'     => 'left',
            'textBoxAlign'  => 'flex-start',
            'width'         => '60%',
            'paddingTop'    => '10px',
            'paddingRight'  => '10px',
            'paddingBottom' => '10px',
            'paddingLeft'   => '10px',
            'marginTop'     => '10px',
            'marginRight'   => 'auto',
            'marginBottom'  => '10px',
            'marginLeft'    => 'auto',
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview page-text-module"
             data-module="PageTextModule"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             style="display: flex; justify-content: <?php echo esc($this->settings['textBoxAlign']); ?>;">
            <div class="text-container"
                 style="width: <?php echo esc($this->settings['width']); ?>;
                        text-align: <?php echo esc($this->settings['textAlign']); ?>;
                        font-size: <?php echo esc($this->settings['fontSize']); ?>;
                        font-weight: <?php echo esc($this->settings['fontWeight']); ?>;
                        font-family: 'Open Sans', sans-serif;
                        padding: <?php echo esc($this->settings['paddingTop']).' '.esc($this->settings['paddingRight']).' '.esc($this->settings['paddingBottom']).' '.esc($this->settings['paddingLeft']); ?>;
                        margin: <?php echo esc($this->settings['marginTop']).' '.esc($this->settings['marginRight']).' '.esc($this->settings['marginBottom']).' '.esc($this->settings['marginLeft']); ?>;">
                <p><?php echo nl2br(esc($this->settings['content'])); ?></p>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        $shortContent = (strlen($this->settings['content']) > 50)
            ? substr($this->settings['content'], 0, 50) . '...'
            : $this->settings['content'];
        return '<button class="module-selector-btn" data-module="PageTextModule">Text Module: '.esc($shortContent).'</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="textContent">Text Content:</label>
            <textarea id="textContent" data-update="content"><?php echo esc($this->settings['content']); ?></textarea>
        </div>

        <div class="form-group">
            <label for="textAlign">Text Alignment:</label>
            <select id="textAlign" data-update="textAlign">
                <option value="left" <?php echo $this->settings['textAlign'] === 'left' ? 'selected' : ''; ?>>Left</option>
                <option value="center" <?php echo $this->settings['textAlign'] === 'center' ? 'selected' : ''; ?>>Center</option>
                <option value="right" <?php echo $this->settings['textAlign'] === 'right' ? 'selected' : ''; ?>>Right</option>
                <option value="justify" <?php echo $this->settings['textAlign'] === 'justify' ? 'selected' : ''; ?>>Justify</option>
            </select>
        </div>

        <div class="form-group">
            <label for="textWidth">Text Width (%):</label>
            <input type="range" id="textWidth" min="10" max="100" value="<?php echo intval($this->settings['width']); ?>" data-update="width">
            <span id="textWidthValue"><?php echo intval($this->settings['width']); ?>%</span>
        </div>

        <div class="form-group">
            <label>Padding:</label>
            <div class="padding-controls">
                <input type="text" id="paddingTop" data-update="paddingTop" value="<?php echo esc($this->settings['paddingTop']); ?>" placeholder="Top">
                <input type="text" id="paddingRight" data-update="paddingRight" value="<?php echo esc($this->settings['paddingRight']); ?>" placeholder="Right">
                <input type="text" id="paddingBottom" data-update="paddingBottom" value="<?php echo esc($this->settings['paddingBottom']); ?>" placeholder="Bottom">
                <input type="text" id="paddingLeft" data-update="paddingLeft" value="<?php echo esc($this->settings['paddingLeft']); ?>" placeholder="Left">
            </div>
        </div>

        <div class="form-group">
            <label>Margin:</label>
            <div class="margin-controls">
                <input type="text" id="marginTop" data-update="marginTop" value="<?php echo esc($this->settings['marginTop']); ?>" placeholder="Top">
                <input type="text" id="marginRight" data-update="marginRight" value="<?php echo esc($this->settings['marginRight']); ?>" placeholder="Right">
                <input type="text" id="marginBottom" data-update="marginBottom" value="<?php echo esc($this->settings['marginBottom']); ?>" placeholder="Bottom">
                <input type="text" id="marginLeft" data-update="marginLeft" value="<?php echo esc($this->settings['marginLeft']); ?>" placeholder="Left">
            </div>
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
