<?php
require_once __DIR__ . '/../../../app/Config/Database.php'; // Load CI4 Database Config

use Config\Database;

// ✅ Establish database connection
$dbConfig = new Database();
$pdo = new PDO(
    "mysql:host={$dbConfig->default['hostname']};dbname={$dbConfig->default['database']};charset={$dbConfig->default['charset']}",
    $dbConfig->default['username'],
    $dbConfig->default['password']
);

// Enable error mode for debugging
$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = $_POST['name'] ?? '';
    $slug = $_POST['slug'] ?? '';
    $data = $_POST['data'] ?? '';

    if (empty($name) || empty($slug) || empty($data)) {
        echo json_encode(['success' => false, 'message' => 'Missing fields']);
        exit;
    }

    // Debugging: Print received data
    error_log("🔵 Received Data: Name: $name, Slug: $slug, Data: " . substr($data, 0, 100) . "...", 0);

    // Check if slug already exists
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM applications WHERE slug = ?");
    $stmt->execute([$slug]);

    if ($stmt->fetchColumn() > 0) {
        echo json_encode(['success' => false, 'message' => 'Slug already in use']);
        exit;
    }

    // Insert application data
    try {
        $stmt = $pdo->prepare("INSERT INTO applications (slug, name, data) VALUES (?, ?, ?)");
        if ($stmt->execute([$slug, $name, $data])) {
            echo json_encode(['success' => true, 'url' => "view_app.php?slug=$slug"]);
        } else {
            echo json_encode(['success' => false, 'message' => 'Database error']);
        }
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
    }
}
