<?php
// modules/LikertScale.php ✅ FINAL - Supports Add/Remove dynamically
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class LikertScale {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('likertScale_');

$defaultSettings = [
    'buttonName'      => 'Likert Scale',
    'buttonPosition'  => 3,
    'mainHeading'     => 'Main Heading',
    'statementColumn' => 'Column One',
    'scaleColumn'     => 'Column Two',
    'statements'      => ['Statement']
];

        $this->settings = array_merge($defaultSettings, $settings);

        if (!is_array($this->settings['statements'])) {
            $this->settings['statements'] = $defaultSettings['statements'];
        }
    }

    public function settingsConfig() {
        return ['mainHeading', 'statementColumn', 'scaleColumn', 'statements'];
    }

    public function render() {
        ob_start(); ?>
        
        <div class="module-preview likert-scale-module" 
             data-module="LikertScale"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             data-settings-config='<?php echo json_encode($this->settingsConfig()); ?>'
             data-statements='<?php echo json_encode($this->settings['statements']); ?>'>
            
            <script>console.log("🔥 LikertScale Rendered: ID => <?php echo esc($this->instanceId); ?>");</script>

            <style>
                .likert-scale-container { max-width: 900px; margin: 0 auto; border: 1px solid #ccc; border-radius: 8px; overflow: hidden; font-family: Arial, sans-serif; }
                .table-main-heading { background: #0d5a82; color: #fff; text-align: center; font-size: 18px; padding: 12px; font-weight: bold; }
                table.likert-scale-table { width: 100%; border-collapse: collapse; }
                table.likert-scale-table thead th { background: #f2d180; text-align: center; padding: 12px; font-size: 16px; border-bottom: 2px solid #ccc; }
                table.likert-scale-table tbody tr { border-bottom: 1px solid #eee; }
                table.likert-scale-table tbody td { padding: 12px; text-align: center; }
                .statement-label { text-align: left; font-weight: bold; width: 30%; }
                .likert-row { white-space: nowrap; }
                .likert-cell { display: inline-block; width: 70px; border: 1px solid #ccc; text-align: center; vertical-align: middle; border-radius: 2px; overflow: hidden; cursor: pointer; box-sizing: border-box; }
                .likert-cell:not(:last-of-type) { border-right: none; }
                .likert-value { background: #d2e5ef; color: #0d5a82; font-weight: bold; font-size: 14px; padding: 8px 0; }
                .likert-radio { background: #fff; padding: 6px 0; }
                .likert-cell:hover .likert-value { background: #c5d9e4; }
                .likert-cell input[type="radio"] { cursor: pointer; }
            </style>

            <div class="likert-scale-container">
                <div class="table-main-heading"><?php echo esc($this->settings['mainHeading']); ?></div>

                <table class="likert-scale-table">
                    <thead>
                        <tr>
                            <th><?php echo esc($this->settings['statementColumn']); ?></th>
                            <th><?php echo esc($this->settings['scaleColumn']); ?></th>
                        </tr>
                    </thead>
                    <tbody id="likert-statements-<?php echo esc($this->instanceId); ?>">
                        <?php foreach ($this->settings['statements'] as $index => $statement): ?>
                        <tr>
                            <td class="statement-label"><?php echo esc($statement); ?></td>
                            <td>
                                <div class="likert-row">
                                    <?php $this->renderScale($index); ?>
                                </div>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <?php return ob_get_clean();
    }

    private function renderScale($rowIndex) {
        $groupName = 'likert_' . $this->instanceId . '_row' . $rowIndex;
        for ($i = 0; $i <= 5; $i++): ?>
            <label class="likert-cell">
                <div class="likert-value"><?php echo $i; ?></div>
                <div class="likert-radio">
                    <input type="radio" name="<?php echo esc($groupName); ?>" value="<?php echo $i; ?>">
                </div>
            </label>
        <?php endfor;
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="LikertScale">'
             . esc($this->settings['buttonName']) . '</button>';
    }
}
?>
