<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class MultiParagraph {
    public $settings = [
        'buttonName' => 'Multi Paragraph',
        'buttonPosition' => 40,
        'rows' => [
            [
                'label' => 'New Row Label',
                'description' => 'Optional description'
            ]
        ]
    ];

    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('multiParagraph_');
        $this->settings = array_merge($this->settings, $settings);

    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview multi-paragraph-module"
             data-module="MultiParagraph"
             data-module-id="<?= esc($this->instanceId); ?>"
             data-settings-config='<?= json_encode($this->settings); ?>'
             style="max-width: 900px; margin: 0 auto; font-family: Arial, sans-serif;">

            <style>
                .multi-paragraph-header {
                    background-color: #074a77;
                    color: #fff;
                    text-align: center;
                    font-size: 18px;
                    font-weight: bold;
                    padding: 12px;
                    border-top-left-radius: 8px;
                    border-top-right-radius: 8px;
                }
                .multi-paragraph-container {
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    overflow: hidden;
                    background-color: #fff;
                }
                .row-title {
                    background: #e7eff2;
                    width: 50%;
                    padding: 15px;
                    border-right: 1px solid #ccc;
                    box-sizing: border-box;
                    color: #074a77;
                    font-weight: bold;
                }
                .row-input {
                    width: 50%;
                    padding: 15px;
                    box-sizing: border-box;
                }
                .multi-paragraph-row {
                    display: flex;
                    border-bottom: 1px solid #ccc;
                }
                .multi-paragraph-row:last-child {
                    border-bottom: none;
                }
                .row-description {
                    color: #074a77;
                    margin-top: 5px;
                    font-style: italic;
                    font-size: 14px;
                }
                .multi-paragraph-textarea {
                    width: 100%;
                    height: 80px;
                    resize: vertical;
                    border: 1px solid #999;
                    border-radius: 4px;
                    padding: 8px;
                    font-family: Arial, sans-serif;
                    font-size: 14px;
                    box-sizing: border-box;
                }
            </style>

            <div class="multi-paragraph-container">
                <div class="multi-paragraph-header">NOW, TAKE TIME TO REFLECT</div>
                <?php foreach ($this->settings['rows'] as $index => $row): ?>
                    <div class="multi-paragraph-row" data-row-index="<?= esc($index); ?>">
                        <div class="row-title">
                            <?= esc($row['label']); ?>
                            <?php if (!empty($row['description'])): ?>
                                <div class="row-description"><?= esc($row['description']); ?></div>
                            <?php endif; ?>
                        </div>
                        <div class="row-input">
                            <textarea class="multi-paragraph-textarea"></textarea>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="MultiParagraph">'
             . esc($this->settings['buttonName']) . '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div id="multiParagraphSettings_<?= esc($this->instanceId); ?>" class="module-settings" style="padding: 10px; background: #f9f9f9; border: 1px solid #ddd; border-radius: 4px; max-width: 600px; margin: 0 auto;">
            <h3 style="margin-bottom: 10px; color: #164986;">Settings<br><small>Multi Paragraph</small></h3>

            <div class="multi-paragraph-rows-list">
                <?php foreach ($this->settings['rows'] as $index => $row): ?>
                    <div class="form-group multi-paragraph-row-settings"
                         data-row-id="<?= esc($index); ?>"
                         style="border: 1px solid #ddd; border-radius: 6px; padding: 10px; margin-bottom: 10px; background: #fff;">

                        <label style="font-weight: bold; color: #164986;">Row Label:</label>
                        <input type="text"
                               class="multi-paragraph-label-input"
                               data-setting="label"
                               data-row-id="<?= esc($index); ?>"
                               value="<?= esc($row['label']); ?>"
                               style="width: 100%; padding: 6px; margin-bottom: 10px; border: 1px solid #ccc; border-radius: 4px;" />

                        <label style="font-weight: bold; color: #164986;">Description:</label>
                        <input type="text"
                               class="multi-paragraph-label-input"
                               data-setting="description"
                               data-row-id="<?= esc($index); ?>"
                               value="<?= esc($row['description']); ?>"
                               style="width: 100%; padding: 6px; border: 1px solid #ccc; border-radius: 4px;" />

                        <button type="button"
                                class="remove-multi-paragraph-row"
                                data-row-id="<?= esc($index); ?>"
                                style="margin-top: 10px; background: #f44336; color: white; border: none; padding: 6px 10px; border-radius: 4px; cursor: pointer;">
                            🗑 Remove Row
                        </button>
                    </div>
                <?php endforeach; ?>
            </div>

            <button class="add-multi-paragraph-row"
                    style="margin-top: 10px; background: #164986; color: #fff; padding: 6px 12px; border: none; border-radius: 4px;">
                ➕ Add Row
            </button>
        </div>
        <?php return ob_get_clean();
    }

    // ✅ Smart merge for nested arrays like rows[]
    private function mergeSettings($defaults, $incoming) {
        foreach ($incoming as $key => $value) {
            if (is_array($value) && isset($defaults[$key]) && is_array($defaults[$key])) {
                $defaults[$key] = $this->mergeSettings($defaults[$key], $value);
            } else {
                $defaults[$key] = $value;
            }
        }
        return $defaults;
    }
}
