<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PageBreak {
    public $settings;
    public $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageBreak_');
        $this->settings = array_merge([
            'pageName'      => 'Untitled',
            'buttonName'    => 'Page Break',
            'buttonPosition'=> 2,
            'leftLogo'      => '',
            'rightLogo'     => '',
            'saveForLater'  => true,
            'finalPage'     => false
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview page-break-module" 
             data-module="PageBreak"
             data-module-id="<?= esc($this->instanceId); ?>"
             data-page-name="<?= esc($this->settings['pageName']); ?>"
             style="border: 1px dashed #ccc; padding: 20px; border-radius: 8px; margin: 10px 0; position: relative;">
            <div class="logo-button-row" style="display: flex; align-items: center; justify-content: space-between; margin-bottom: 15px;">
                <div class="logo-circle left-logo" style="width: 80px; height: 80px; border-radius: 50%; background-color: #666; display: flex; align-items: center; justify-content: center; color: #fff; font-weight: bold;">
                    <?= $this->settings['leftLogo']
                        ? '<img src="'.esc($this->settings['leftLogo']).'" alt="Left Logo" style="width: 100%; height: auto; border-radius: 50%;">'
                        : 'LOGO' ?>
                </div>

                <div class="navigation-buttons" style="display: flex; align-items: center; gap: 10px;">
                    <button class="bottom-button previous-button" data-prev-btn style="background: #2c3e8f; color: #fff; display:none;">Previous</button>
                    <button class="bottom-button next-button" data-page-btn data-final-page="<?= ($this->settings['finalPage']) ? 'true' : 'false'; ?>" style="background: #2c3e8f; color: #fff;">
                        <?= esc($this->settings['finalPage'] ? 'Submit' : 'Next'); ?>
                    </button>
                    
                    <!-- Save for Later button (default visible) -->
                    <button id="saveForLaterButton_<?= esc($this->instanceId); ?>" class="bottom-button save-later-button" data-save-btn="" style="background: #2c3e8f; color: #fff; display: inline-block;">
                        Save for later
                    </button>

                </div>

                <div class="logo-circle right-logo" style="width: 80px; height: 80px; border-radius: 50%; background-color: #666; display: flex; align-items: center; justify-content: center; color: #fff; font-weight: bold;">
                    <?= $this->settings['rightLogo']
                        ? '<img src="'.esc($this->settings['rightLogo']).'" alt="Right Logo" style="width: 100%; height: auto; border-radius: 50%;">'
                        : 'LOGO' ?>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        $buttonName = esc($this->settings['buttonName']);
        return '<button class="module-selector-btn" data-module="PageBreak">' . $buttonName . '</button>';
    }

    public function renderSettings($pageBreakNumber = 1) {
        ob_start(); ?>
        <div class="module-settings" style="padding: 15px; background: #f9f9f9; border: 1px solid #ddd; border-radius: 6px; max-width: 500px; margin: 0 auto;">
            <div class="module-settings-title" style="color: #164986; font-weight: bold; font-size: 1.17em; margin-bottom: 15px;">
                Module Settings:<br>Page Break #<?= esc($pageBreakNumber); ?>
            </div>

            <div class="form-group" style="margin-bottom: 15px;">
                <label>Page Name:</label>
                <input type="text" id="pageName_<?= esc($this->instanceId); ?>" 
                       class="page-name-input" 
                       style="width: 100%; padding: 8px; border: 1px solid #ccc; border-radius: 4px;"
                       value="<?= esc($this->settings['pageName']); ?>"
                       data-target-module-id="<?= esc($this->instanceId); ?>">
            </div>

            <!-- Left Logo Image Picker -->
            <div class="form-group" style="margin-bottom: 15px;">
                <label>Left Logo:</label><br>
                <input type="hidden" id="leftLogoInput_<?= esc($this->instanceId); ?>" value="<?= esc($this->settings['leftLogo']); ?>">
                <img id="leftLogoPreview_<?= esc($this->instanceId); ?>" src="<?= esc($this->settings['leftLogo']); ?>" style="max-width: 120px; margin-bottom: 10px;">
                <button type="button" onclick="openImageUploadModal(function(url) {
                    document.getElementById('leftLogoPreview_<?= esc($this->instanceId); ?>').src = url;
                    document.getElementById('leftLogoInput_<?= esc($this->instanceId); ?>').value = url;
                });">Select Left Logo</button>
            </div>

            <!-- Right Logo Image Picker -->
            <div class="form-group" style="margin-bottom: 15px;">
                <label>Right Logo:</label><br>
                <input type="hidden" id="rightLogoInput_<?= esc($this->instanceId); ?>" value="<?= esc($this->settings['rightLogo']); ?>">
                <img id="rightLogoPreview_<?= esc($this->instanceId); ?>" src="<?= esc($this->settings['rightLogo']); ?>" style="max-width: 120px; margin-bottom: 10px;">
                <button type="button" onclick="openImageUploadModal(function(url) {
                    document.getElementById('rightLogoPreview_<?= esc($this->instanceId); ?>').src = url;
                    document.getElementById('rightLogoInput_<?= esc($this->instanceId); ?>').value = url;
                });">Select Right Logo</button>
            </div>

            <!-- Save for Later Checkbox and Logic -->
            <div class="form-group" style="margin-bottom: 15px; padding: 0;">
                <label for="saveForLater_<?= esc($this->instanceId); ?>" 
                       style="display: inline-flex; align-items: center; gap: 6px; white-space: nowrap; padding: 0; margin: 0;">
                    <input type="checkbox" 
                           id="saveForLater_<?= esc($this->instanceId); ?>" 
                           class="save-for-later-checkbox"
                           style="margin: 0; padding: 0; vertical-align: middle;"
                           <?= $this->settings['saveForLater'] ? 'checked' : ''; ?>>
                    <span style="display:inline-block; vertical-align: middle; color: #164986; font-weight: 500;">Save for Later</span>
                </label>
            </div>

        </div>

        <script>
            // Toggle the visibility of the "Save for Later" button based on the checkbox state
            document.getElementById('saveForLater_<?= esc($this->instanceId); ?>').addEventListener('change', function() {
                const button = document.querySelector('#saveForLaterButton_<?= esc($this->instanceId); ?>');
                button.style.display = this.checked ? 'inline-block' : 'none';
            });
        </script>

        <?php
        return ob_get_clean();
    }
}
?>
