<?php
class ParagraphTextAndScripture {
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('paragraphScripture_');
    }

    private function mergeSettings($settings) {
        return array_merge([
            'buttonName'     => 'Paragraph or Scripture',
            'buttonPosition' => 5,
            'contentType'    => 'paragraph',
            'content'        => 'This is your main paragraph or scripture text.',
            'scriptureRef'   => 'Matthew 6:15',
            'fontSize'       => '18px',
            'textAlign'      => 'left',
            'textBoxAlign'   => 'center',
            'width'          => '80%',
            'paddingTop'     => '10px',
            'paddingRight'   => '10px',
            'paddingBottom'  => '10px',
            'paddingLeft'    => '10px',
            'marginTop'      => '10px',
            'marginRight'    => 'auto',
            'marginBottom'   => '10px',
            'marginLeft'     => 'auto',
        ], $settings);
    }

    public function render($settings = []) {
        $s = $this->mergeSettings($settings); // ✅ Ensures updated settings are used
        $id = htmlspecialchars($this->instanceId);
        $containerStyles = "display: flex; justify-content: {$s['textBoxAlign']}; margin: {$s['marginTop']} {$s['marginRight']} {$s['marginBottom']} {$s['marginLeft']};";
        $contentStyles = "width: {$s['width']}; text-align: {$s['textAlign']}; font-size: {$s['fontSize']}; font-family: 'Open Sans', sans-serif; padding: {$s['paddingTop']} {$s['paddingRight']} {$s['paddingBottom']} {$s['paddingLeft']};";

        ob_start(); ?>
        <div class="module-preview"
             data-module="ParagraphTextAndScripture"
             data-module-id="<?= $id ?>"
             id="module-<?= $id ?>"
             style="<?= $containerStyles ?>">
            <div class="content-block" style="<?= $contentStyles ?>">
                <?php if ($s['contentType'] === 'scripture'): ?>
                    <p style="font-style: italic;"><?= nl2br($s['content']) ?></p>
                    <div class="scripture-ref" style="text-align: right; font-weight: bold; margin-top: 5px;">
                        — <?= htmlspecialchars($s['scriptureRef']) ?>
                    </div>
                <?php else: ?>
                    <p><?= nl2br($s['content']) ?></p>
                <?php endif; ?>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ParagraphTextAndScripture">Paragraph or Scripture</button>';
    }

    public function renderSettings($settings = []) {
        $s = $this->mergeSettings($settings);
        $id = htmlspecialchars($this->instanceId);

        ob_start(); ?>
        <div class="module-settings" data-module="ParagraphTextAndScripture" id="paragraphTextAndScriptureSettings_<?= $id ?>">
            <div class="settings-panel">
                <label>Content Type:</label>
                <select data-setting="contentType">
                    <option value="paragraph" <?= $s['contentType'] === 'paragraph' ? 'selected' : '' ?>>Standard Paragraph</option>
                    <option value="scripture" <?= $s['contentType'] === 'scripture' ? 'selected' : '' ?>>Scripture</option>
                </select>

                <label>Main Content:</label>
                <textarea data-setting="content" style="width: 100%; min-height: 100px;"><?= htmlspecialchars($s['content']) ?></textarea>

                <div class="scripture-settings" style="<?= $s['contentType'] === 'scripture' ? '' : 'display:none;' ?>">
                    <label>Scripture Reference:</label>
                    <input type="text" data-setting="scriptureRef" value="<?= htmlspecialchars($s['scriptureRef']) ?>" />
                </div>

                <label>Font Size:</label>
                <input type="text" data-setting="fontSize" value="<?= htmlspecialchars($s['fontSize']) ?>" />

                <label>Text Align:</label>
                <select data-setting="textAlign">
                    <option value="left" <?= $s['textAlign'] === 'left' ? 'selected' : '' ?>>Left</option>
                    <option value="center" <?= $s['textAlign'] === 'center' ? 'selected' : '' ?>>Center</option>
                    <option value="right" <?= $s['textAlign'] === 'right' ? 'selected' : '' ?>>Right</option>
                </select>

                <label>Width:</label>
                <input type="text" data-setting="width" value="<?= htmlspecialchars($s['width']) ?>" />
            </div>
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
