<?php
// modules/ScoreSummary.php - Final Version with Show Average fix and aligned checkboxes

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ScoreSummary {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('scoreSummary_');
        $this->settings = array_merge([
            'buttonName'    => 'Score Summary',
            'headingText'   => 'Which type of spiritual identity do you primarily carry: an orphan or a son?',
            'scoreLabel'    => 'Your total score (out of 105):',
            'scoreValue'    => '95',
            'averageValue'  => '8',
            'showAverage'   => '1', // Default checked
            'rangeHeading'  => 'Scoring Ranges:',
            'range1Min'     => '21',
            'range1Max'     => '42',
            'range1Label'   => 'Spirit of an Orphan',
            'range2Min'     => '43',
            'range2Max'     => '83',
            'range2Label'   => 'A Season of Spiritual Transition',
            'range3Min'     => '84',
            'range3Max'     => '105',
            'range3Label'   => 'Spirit of a Son',
            'selectedModules' => [],
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        
    <!-- Instructional Text ABOVE the container -->
    <div style="max-width: 1100px; margin: 0 auto; font-family: Arial, sans-serif; color: #444; font-size: 16px; text-align: center; padding: 15px;">
        Give yourself a score from 1 to 10 depending on how consistently you demonstrate "the mature viewpoint".<br>
        For your reference, we have included "the immature/soulish viewpoint" as well.
    </div>

        <div class="module-preview score-summary-module"
             data-module="ScoreSummary"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <style>
                .score-summary-container {
                    width: 50%;
                    margin: 0 auto;
                    font-family: Arial, sans-serif;
                    color: #333;
                }
                .score-question {
                    font-weight: normal;
                    font-size: 32px;
                    margin: 32px 0;
                    text-align: center;
                }
                .score-label {
                    font-weight: bold;
                    font-size: 32px;
                }
                .score-line {
                    display: flex;
                    align-items: center;
                    justify-content: center;
                    margin-bottom: 32px;
                }
                .score-line .score-label {
                    margin-right: 16px;
                }
                .score-box {
                    padding: 8px 24px;
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    font-weight: bold;
                    background: #fff;
                    min-width: 80px;
                    text-align: center;
                    font-size: 28px;
                    color: #074a77;
                }
                .scoring-heading {
                    margin-top: 48px;
                    font-size: 32px;
                    font-weight: bold;
                    text-align: center;
                }
                .range-item {
                    margin: 16px 0;
                    font-size: 28px;
                    text-align: center;
                }
                .average-line {
                    display: flex;
                    align-items: center;
                    justify-content: center;
                    margin-bottom: 32px;
                }
                .average-label {
                    font-weight: bold;
                    font-size: 32px;
                    margin-right: 16px;
                }
            </style>

            <div class="score-summary-container">
                <div class="score-question">
                    <?php echo esc($this->settings['headingText']); ?>
                </div>

                <div class="score-line">
                    <div class="score-label"><?php echo esc($this->settings['scoreLabel']); ?></div>
                    <div class="score-box"><?php echo esc($this->settings['scoreValue']); ?></div>
                </div>

                <?php if (!empty($this->settings['showAverage'])): ?>
                <div class="average-line">
                    <div class="average-label">Your average score:</div>
                    <div class="score-box"><?php echo esc($this->settings['averageValue']); ?></div>
                </div>
                <?php endif; ?>

                <div class="scoring-heading"><?php echo esc($this->settings['rangeHeading']); ?></div>
                <div class="range-item"><?php echo esc($this->settings['range1Min']); ?> - <?php echo esc($this->settings['range1Max']); ?>: <?php echo esc($this->settings['range1Label']); ?></div>
                <div class="range-item"><?php echo esc($this->settings['range2Min']); ?> - <?php echo esc($this->settings['range2Max']); ?>: <?php echo esc($this->settings['range2Label']); ?></div>
                <div class="range-item"><?php echo esc($this->settings['range3Min']); ?> - <?php echo esc($this->settings['range3Max']); ?>: <?php echo esc($this->settings['range3Label']); ?></div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ScoreSummary">'
             . esc($this->settings['buttonName']) . '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="headingText">Heading/Question:</label>
            <input type="text" id="headingText" data-update="headingText"
                   value="<?php echo esc($this->settings['headingText']); ?>">
        </div>

        <div class="form-group">
            <label for="scoreLabel">Score Label:</label>
            <input type="text" id="scoreLabel" data-update="scoreLabel"
                   value="<?php echo esc($this->settings['scoreLabel']); ?>">
        </div>

        <!-- Show Average Checkbox (label first, aligned) -->
        <div class="form-group" style="display: flex; align-items: center;">
            <label for="showAverage" style="margin-right: 8px;">Show Average</label>
            <input type="checkbox" id="showAverage" data-update="showAverage" value="1" <?php echo (!empty($this->settings['showAverage'])) ? 'checked' : ''; ?>>
        </div>

        <hr>

        <div class="form-group">
            <label for="rangeHeading">Scoring Ranges Heading:</label>
            <input type="text" id="rangeHeading" data-update="rangeHeading"
                   value="<?php echo esc($this->settings['rangeHeading']); ?>">
        </div>

        <!-- Full Range Controls -->
        <div class="form-group">
            <label>Range 1:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range1Min" 
                       value="<?php echo esc($this->settings['range1Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range1Max" 
                       value="<?php echo esc($this->settings['range1Max']); ?>" style="width:50px;">
                <input type="text" data-update="range1Label" 
                       value="<?php echo esc($this->settings['range1Label']); ?>" style="flex:1;">
            </div>
        </div>

        <div class="form-group">
            <label>Range 2:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range2Min" 
                       value="<?php echo esc($this->settings['range2Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range2Max" 
                       value="<?php echo esc($this->settings['range2Max']); ?>" style="width:50px;">
                <input type="text" data-update="range2Label" 
                       value="<?php echo esc($this->settings['range2Label']); ?>" style="flex:1;">
            </div>
        </div>

        <div class="form-group">
            <label>Range 3:</label>
            <div style="display:flex; gap:6px;">
                <input type="text" data-update="range3Min" 
                       value="<?php echo esc($this->settings['range3Min']); ?>" style="width:50px;">
                <span>-</span>
                <input type="text" data-update="range3Max" 
                       value="<?php echo esc($this->settings['range3Max']); ?>" style="width:50px;">
                <input type="text" data-update="range3Label" 
                       value="<?php echo esc($this->settings['range3Label']); ?>" style="flex:1;">
            </div>
        </div>

        <hr>

<!-- Aligned Likert checkboxes (Label first, inline, no wrapping) -->
<div class="form-group">
    <label>Select Modules to Sum:</label><br>
    <small>These controls are placeholders for future functionality.</small>
    <div style="margin-top:8px;">
        <div style="display: flex; flex-direction: column; gap: 8px;">
            <div style="display: flex; align-items: center; gap: 8px; white-space: nowrap;">
                <label for="likert1" style="margin: 0;">Likert 1</label>
                <input type="checkbox" id="likert1" data-update="selectedModules" value="Likert1">
            </div>
            <div style="display: flex; align-items: center; gap: 8px; white-space: nowrap;">
                <label for="likert2" style="margin: 0;">Likert 2</label>
                <input type="checkbox" id="likert2" data-update="selectedModules" value="Likert2">
            </div>
            <div style="display: flex; align-items: center; gap: 8px; white-space: nowrap;">
                <label for="likert3" style="margin: 0;">Likert 3</label>
                <input type="checkbox" id="likert3" data-update="selectedModules" value="Likert3">
            </div>
            <div style="display: flex; align-items: center; gap: 8px; white-space: nowrap;">
                <label for="likert4" style="margin: 0;">Likert 4</label>
                <input type="checkbox" id="likert4" data-update="selectedModules" value="Likert4">
            </div>
            <div style="display: flex; align-items: center; gap: 8px; white-space: nowrap;">
                <label for="likert5" style="margin: 0;">Likert 5</label>
                <input type="checkbox" id="likert5" data-update="selectedModules" value="Likert5">
            </div>
        </div>
    </div>
</div>

        <?php
        return ob_get_clean();
    }
}
?>
