<?php
namespace App\ModulesV2;

class ParagraphTextAndScripture_v2 {
    private $instanceId;
    private $settings;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('paragraphScripture_');
        $this->settings = array_merge([
            'buttonName'     => 'Paragraph or Scripture (V2)',
            'contentType'    => 'paragraph',
            'content'        => 'This is your paragraph or scripture.',
            'scriptureRef'   => 'John 3:16',
            'fontSize'       => '18px',
            'textAlign'      => 'left',
            'width'          => '80%',
        ], $settings);
    }

    public function render($settings = []) {
        $s = array_merge($this->settings, $settings);
        $id = $this->instanceId;

        ob_start(); ?>
        <div class="module-preview"
             id="module-<?= $id ?>"
             data-module="ParagraphTextAndScripture_v2"
             data-module-id="<?= $id ?>">
            <div class="content" style="text-align: <?= $s['textAlign'] ?>; font-size: <?= $s['fontSize'] ?>; width: <?= $s['width'] ?>;">
                <?php if ($s['contentType'] === 'scripture'): ?>
                    <p style="font-style: italic;"><?= nl2br($s['content']) ?></p>
                    <div style="text-align: right; font-weight: bold;">— <?= $s['scriptureRef'] ?></div>
                <?php else: ?>
                    <p><?= nl2br($s['content']) ?></p>
                <?php endif; ?>
            </div>
        </div>
        <?php return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ParagraphTextAndScripture_v2">Paragraph or Scripture (V2)</button>';
    }

    public function renderSettings($settings = []) {
        $s = array_merge($this->settings, $settings);
        $id = $this->instanceId;

        ob_start(); ?>
        <div class="module-settings" id="settings-<?= $id ?>" data-instance-id="<?= $id ?>">
            <label>Content Type:</label>
            <select data-setting="contentType">
                <option value="paragraph" <?= $s['contentType'] === 'paragraph' ? 'selected' : '' ?>>Paragraph</option>
                <option value="scripture" <?= $s['contentType'] === 'scripture' ? 'selected' : '' ?>>Scripture</option>
            </select>

            <label>Main Content:</label>
            <textarea data-setting="content"><?= htmlspecialchars($s['content']) ?></textarea>

            <label>Scripture Reference:</label>
            <input type="text" data-setting="scriptureRef" value="<?= $s['scriptureRef'] ?>" />

            <label>Font Size:</label>
            <input type="text" data-setting="fontSize" value="<?= $s['fontSize'] ?>" />

            <label>Text Align:</label>
            <select data-setting="textAlign">
                <option value="left" <?= $s['textAlign'] === 'left' ? 'selected' : '' ?>>Left</option>
                <option value="center" <?= $s['textAlign'] === 'center' ? 'selected' : '' ?>>Center</option>
                <option value="right" <?= $s['textAlign'] === 'right' ? 'selected' : '' ?>>Right</option>
            </select>

            <label>Width:</label>
            <input type="text" data-setting="width" value="<?= $s['width'] ?>" />
        </div>

        <script>
        (function(){
            const instanceId = "<?= $id ?>";
            const wrapper = document.getElementById("settings-<?= $id ?>");
            if (!wrapper) {
                console.error("❌ Could not find wrapper for settings.");
                return;
            }

            console.log("✅ Settings wrapper found for:", instanceId);

            const inputs = wrapper.querySelectorAll('[data-setting]');
            console.log("🎯 Found", inputs.length, "inputs");

            inputs.forEach(input => {
                const key = input.getAttribute('data-setting');

                input.addEventListener('input', () => {
                    const newVal = input.value;
                    console.log(`📝 Input [${key}] =>`, newVal);

                    const settings = window.moduleSettings[instanceId] || {};
                    settings[key] = newVal;
                    window.moduleSettings[instanceId] = settings;

                    window.updateModuleSettings(instanceId, settings);
                });

                input.addEventListener('focus', () => {
                    console.log(`👀 Focused on input [${key}]`);
                });

                input.addEventListener('change', () => {
                    console.log(`📤 Changed [${key}] to`, input.value);
                });
            });
        })();
        </script>
        <?php return ob_get_clean();
    }
}
?>
