<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>App Creator Dashboard V2</title>
  <meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">
  <meta http-equiv="Pragma" content="no-cache">
  <meta http-equiv="Expires" content="0">
  <link href="https://fonts.googleapis.com/css?family=Roboto:400,500,700&display=swap" rel="stylesheet">
  <link rel="stylesheet" href="<?= base_url('css/app_styles.css'); ?>?v=<?= time(); ?>">
  <link rel="stylesheet" href="<?= base_url('css/modules.css'); ?>?v=<?= time(); ?>">

  <!-- Global function definitions -->
  <script>
    // Define openEditor so inline onclick attributes can find it.
    window.openEditor = window.openEditor || function() {
        var editorEl = document.getElementById('pageTextEditor');
        if (!editorEl) {
            console.error("openEditor: Cannot find element with ID 'pageTextEditor'");
            return;
        }
        var content = editorEl.value;
        console.log("openEditor called with content:", content);
        if (typeof window.openTinyMCEModal === 'function') {
            // Open the TinyMCE modal; its save button will update both the textarea and preview.
            window.openTinyMCEModal(content, function(updatedContent) {
                // Update the hidden textarea (this callback may be used for internal updates, if needed)
                editorEl.value = updatedContent;
                console.log("Content updated via modal callback:", updatedContent);
                alert("Content updated! (Remember, preview will update when you click Save in the modal.)");
            });
        } else {
            console.error("openTinyMCEModal is not defined on window.");
            alert("Editor function is not available.");
        }
    };
  </script>
</head>
<body>

<div class="top-bar">
    <h1>App Creator Dashboard V2</h1>
    <div class="app-info">
        <input type="text" id="app-name" placeholder="App Name">
        <input type="text" id="app-slug" placeholder="App Slug">
        <button id="saveApp" class="btn save-btn">Save Application</button>
    </div>
    <div class="controls">
        <button class="btn undo-btn">Undo</button>
        <button class="btn redo-btn">Redo</button>
    </div>
</div>

<div id="app-builder">
    <div class="sidebar">
        <h2>Modules</h2>
        <ul>
            <?php foreach ($modules as $mod): ?>
                <li>
                    <button class="module-selector-btn" 
                            data-module="<?= esc($mod['name']); ?>" 
                            draggable="true"
                            onmouseover="showModulePreview('<?= esc($mod['name']); ?>', this)"
                            onmouseout="hideModulePreview()">
                        <?= esc($mod['buttonName']); ?>
                    </button>
                </li>
            <?php endforeach; ?>
        </ul>
    </div>

    <div class="canvas" id="canvas">
        <h2>Your App Preview</h2>
    </div>

    <div class="settings" id="settings-pane">
        <div id="settings-content">
            <p>Select a module to edit its settings.</p>
        </div>
    </div>
</div>



<!-- ✅ TinyMCE Modal -->
<div id="tinymceModal" style="position: fixed; top: 0; left: 0; right: 0; bottom: 0; background: rgba(0,0,0,0.7); display: none; align-items: center; justify-content: center; z-index: 9999;">
  <div style="background: #fff; padding: 20px; width: 70%; max-width: 800px; border-radius: 8px; position: relative;">
      <textarea id="tinymceEditor" style="width: 100%; height: 300px;"></textarea>
      <div style="margin-top: 15px; text-align: right;">
          <button id="saveTinyContent" style="background-color: #2c3e8f; color: #fff; padding: 10px 20px; border: none; border-radius: 4px;">Save</button>
          <button id="cancelTinyContent" style="margin-left: 10px; padding: 10px 20px; border: 1px solid #ccc; border-radius: 4px;">Cancel</button>
      </div>
  </div>
</div>

<!-- ✅ Image Upload Modal -->
<div id="imageUploadModal" style="display:none; position:fixed; top:0; left:0; width:100%; height:100%; background: rgba(0,0,0,0.7); z-index:9999; align-items:center; justify-content:center;">
  <div style="background:#fff; padding:20px; max-width:800px; width:90%; border-radius:8px; position:relative;">
    <h2>Select or Upload Image</h2>
    <div id="image-list" style="display:flex; flex-wrap:wrap; gap:10px; margin-bottom:15px;"></div>
    <input type="file" id="uploadImageInput" accept="image/*" style="margin-bottom:15px;">
    <button id="uploadImageBtn" class="btn">Upload</button>
    <button id="closeImageModal" class="btn" style="background:#ccc; margin-left:10px;">Close</button>
  </div>
</div>

<!-- ✅ Floating Hover Preview -->
<div id="module-preview-popup" style="display:none; position:absolute; background:#fff; border:1px solid #ccc; padding:10px; z-index:1000; max-width:400px; box-shadow:0 2px 8px rgba(0,0,0,0.3); border-radius:8px;"></div>

<!-- ✅ TinyMCE & Core JS -->
<script src="<?= base_url('js/tinymce/tinymce.min.js'); ?>"></script>

<!-- Inject Module Markup and Settings Markup from PHP -->
<script>
  window.moduleMarkup = window.moduleMarkup || <?= json_encode($moduleMarkup); ?>;
  window.moduleSettingsMarkup = window.moduleSettingsMarkup || <?= json_encode($moduleSettingsMarkup); ?>;
</script>

<!-- ✅ TinyMCE Logic -->
<script>
  window.tinyCallback = window.tinyCallback || null;
  function openTinyModal(content, callback) {
      window.tinyCallback = callback;
      document.getElementById('tinymceModal').style.display = 'flex';
      tinymce.init({
          selector: '#tinymceEditor',
          menubar: false,
          height: 300,
          plugins: 'link lists code',
          toolbar: 'undo redo | bold italic underline | bullist numlist | alignleft aligncenter alignright | link | code',
          setup: function (editor) { editor.on('init', () => editor.setContent(content)); }
      });
  }
  document.addEventListener('DOMContentLoaded', () => {
      document.getElementById('saveTinyContent')?.addEventListener('click', () => {
          // Get the updated content from TinyMCE
          const content = tinymce.get('tinymceEditor').getContent();
          // Update the hidden textarea value
          var editorEl = document.getElementById('pageTextEditor');
          if (editorEl) {
              editorEl.value = content;
          }
          // Immediately update the live preview if a module is selected
          var selectedModule = document.querySelector('.module-preview.selected');
          if (selectedModule) {
              var textElement = selectedModule.querySelector('.text-container p');
              if (textElement) {
                  textElement.innerHTML = content;
                  console.log("Module preview updated with new content via TinyMCE save.");
              } else {
                  console.warn("No text element found in the selected module.");
              }
          } else {
              console.warn("No module is selected; cannot update preview.");
          }
          if (window.tinyCallback) window.tinyCallback(content);
          tinymce.get('tinymceEditor').destroy();
          document.getElementById('tinymceModal').style.display = 'none';
      });
      document.getElementById('cancelTinyContent')?.addEventListener('click', () => {
          tinymce.get('tinymceEditor').destroy();
          document.getElementById('tinymceModal').style.display = 'none';
      });
  });
</script>

<!-- ✅ Hover Preview Logic -->
<script>
function showModulePreview(moduleName, buttonEl) {
    const previewEl = document.getElementById('module-preview-popup');
    const html = window.moduleMarkup[moduleName];
    if (!html) return;
    previewEl.innerHTML = html;
    previewEl.style.display = 'block';
    previewEl.style.top = (buttonEl.getBoundingClientRect().bottom + window.scrollY + 10) + 'px';
    previewEl.style.left = (buttonEl.getBoundingClientRect().right + window.scrollX + 10) + 'px';
}
function hideModulePreview() {
    document.getElementById('module-preview-popup').style.display = 'none';
}
</script>

<!-- ✅ Core App Scripts -->
<script src="<?= base_url('js/settings-panel.js'); ?>?v=<?= time(); ?>"></script>
<script src="<?= base_url('js/module-builder.js'); ?>?v=<?= time(); ?>"></script>
<!-- ✅ New Image Upload JS -->
<script src="<?= base_url('js/image-upload-modal.js'); ?>?v=<?= time(); ?>"></script>
<script src="<?= base_url('js/settings/multiParagraph.js'); ?>?v=<?= time(); ?>"></script>
<script src="<?= base_url('js/settings/paragraphTextAndScripture.js'); ?>?v=<?= time(); ?>"></script>


<!-- Save Application Logic (optional) -->
<script>
document.addEventListener('DOMContentLoaded', function(){
    document.getElementById('saveApp').addEventListener('click', function(){
        var updatedContent = document.getElementById('pageTextEditor').value;
        var selectedModule = document.querySelector('.module-preview.selected');
        if(selectedModule){
            var textElement = selectedModule.querySelector('.text-container p');
            if(textElement){
                textElement.innerHTML = updatedContent;
                console.log("Module preview updated with new content upon saving the app.");
            } else {
                console.warn("No text element found in the selected module.");
            }
        } else {
            console.warn("No module is selected; cannot update preview.");
        }
        // Insert your AJAX save logic here.
        alert("Application saved with updated text: " + updatedContent);
    });
});
</script>





</body>
</html>
