<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Image Upload</title>
    <style>
        .image-thumb {
            width: 100px;
            height: 100px;
            object-fit: cover;
        }
        .image-container {
            display: flex;
            gap: 10px;
        }
        .image-container button {
            margin-top: 5px;
        }
    </style>
</head>
<body>

<h1>Upload Image</h1>

<!-- Upload Form -->
<form id="uploadForm" enctype="multipart/form-data">
    <input type="file" name="image" id="image" accept="image/*">
    <button type="submit">Upload</button>
</form>

<!-- Display uploaded images -->
<h2>Uploaded Images</h2>
<div class="image-container" id="imageContainer"></div>

<!-- Modal to Select Image -->
<div id="imageModal" style="display:none; position: fixed; top: 0; left: 0; right: 0; bottom: 0; background: rgba(0,0,0,0.5); text-align: center; padding-top: 50px;">
    <div style="background-color: #fff; padding: 20px;">
        <h3>Select an Image</h3>
        <div class="image-container" id="modalImageContainer"></div>
        <button onclick="closeModal()">Close</button>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        // Handle the image upload
        const uploadForm = document.getElementById('uploadForm');
        uploadForm.addEventListener('submit', function (e) {
            e.preventDefault();
            const formData = new FormData(uploadForm);
            fetch('<?= base_url("upload/upload"); ?>', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('Image uploaded successfully!');
                    loadImages();
                } else {
                    alert('Image upload failed: ' + data.error);
                }
            });
        });

        // Fetch and display existing images
        loadImages();

        // Load images into the page
        function loadImages() {
            fetch('<?= base_url("upload/getImages"); ?>')
            .then(response => response.json())
            .then(images => {
                const container = document.getElementById('imageContainer');
                container.innerHTML = '';
                images.forEach(image => {
                    const img = document.createElement('img');
                    img.src = '<?= base_url("uploads/"); ?>' + image;
                    img.classList.add('image-thumb');
                    img.addEventListener('click', function () {
                        openModal(image);
                    });
                    container.appendChild(img);
                });
            });
        }

        // Open the modal with the selected image
        function openModal(image) {
            const modal = document.getElementById('imageModal');
            const modalContainer = document.getElementById('modalImageContainer');
            modalContainer.innerHTML = `<img src="<?= base_url('uploads/'); ?>${image}" class="image-thumb">`;
            modal.style.display = 'block';
        }

        // Close the modal
        function closeModal() {
            document.getElementById('imageModal').style.display = 'none';
        }
    });
</script>

</body>
</html>
