function openTinyMCEModal(existingContent, callback) {
    const modal = document.getElementById('tinymceModal');
    const editorArea = document.getElementById('tinymceEditor');
    const saveBtn = document.getElementById('saveTinyContent');
    const cancelBtn = document.getElementById('cancelTinyContent');

    console.log("openTinyMCEModal called with content:", existingContent);

    if (tinymce.get('tinymceEditor')) {
        tinymce.get('tinymceEditor').setContent(existingContent);
        console.log("TinyMCE already exists. Content updated.");
    } else {
        editorArea.value = existingContent;
        tinymce.init({
            selector: '#tinymceEditor',
            menubar: false,
            plugins: 'lists link code',
            toolbar: 'undo redo | styleselect | bold italic underline | alignleft aligncenter alignright | bullist numlist | code',
            height: 300
        });
        console.log("Initializing TinyMCE editor.");
    }

    modal.style.display = 'flex';
    console.log("Modal displayed.");

    saveBtn.onclick = () => {
        const updatedContent = tinymce.get('tinymceEditor').getContent();
        console.log("Save clicked. Updated content:", updatedContent);
        modal.style.display = 'none';
        callback(updatedContent);
    };

    cancelBtn.onclick = () => {
        console.log("Cancel clicked. Closing modal.");
        modal.style.display = 'none';
    };
}


document.addEventListener('DOMContentLoaded', function () {
    const settingsPanel = document.getElementById('settings-pane');
    const canvas = document.getElementById('canvas');

    // Load Module Settings When a Module is Clicked
    window.loadModuleSettings = function (module, moduleType) {
        console.log("Loading settings for module type:", moduleType);
        settingsPanel.innerHTML = ''; // Clear previous settings

        const settingsHTML = moduleSettingsMarkup[moduleType] || null;

        if (settingsHTML) {
            settingsPanel.innerHTML = `
                <h2>Module Settings</h2>
                ${settingsHTML}
            `;

            const textContainer = module.querySelector('.text-container');
            if (!textContainer) {
                console.warn("No text container found in module");
                return;
            }

            // Auto-detect inputs and apply updates dynamically
            settingsPanel.querySelectorAll('[data-update]').forEach(input => {
                const settingName = input.getAttribute('data-update');

                if (settingName === "content") {
                    input.value = textContainer.querySelector('p').innerHTML;
                    console.log("Content input initialized with:", input.value);

                    // Add click listener to open TinyMCE modal on settings textarea
                    input.addEventListener('click', function (e) {
                        e.stopPropagation();
                        console.log("Settings panel content textarea clicked.");
                        openTinyMCEModal(input.value, function (updatedContent) {
                            console.log("Modal callback received updated content.");
                            input.value = updatedContent;
                            textContainer.querySelector('p').innerHTML = updatedContent;
                        });
                    });
                } else {
                    input.value = textContainer.style[settingName] || "";
                }

                input.addEventListener('input', function () {
                    applySettingToModule(module, settingName, this.value);
                });
            });
        } else {
            settingsPanel.innerHTML = '<h2>No settings defined for this module.</h2>';
            console.warn("No settings HTML defined for module type:", moduleType);
        }
    };

    // Apply Changes Dynamically to Selected Module
    function applySettingToModule(module, setting, value) {
        const textContainer = module.querySelector('.text-container');
        if (!textContainer) return;

        if (setting === "content") {
            textContainer.querySelector('p').innerHTML = value;
        } else {
            textContainer.style[setting] = value;
        }
    }

    // Detect clicks on modules and load settings
    canvas.addEventListener('click', function (e) {
        const clickedModule = e.target.closest('.module-preview');
        if (clickedModule) {
            document.querySelectorAll('.module-preview').forEach(m => m.classList.remove('selected'));
            clickedModule.classList.add('selected');
            const moduleType = clickedModule.getAttribute('data-module');
            console.log("Module clicked with ID:", clickedModule.getAttribute('data-module-id'));
            loadModuleSettings(clickedModule, moduleType);
        }
    });
});
