<?php
// modules/PersonalTestimony.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PersonalTestimony {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('personalTestimony_');
        $this->settings = array_merge([
            'buttonName'     => 'Personal Testimony',
            'sectionTitle'   => '...Teach my Sons to Develop a Personal Testimony?',
            'scoreLabel'     => 'SCORE',
            'verseText'      => 'And they overcame him {Satan} by the blood of the Lamb and by the word of their testimony, and they did not love their lives to the death.<br><strong>Revelations 12:11</strong><br><br>"Therefore you are My witnesses," says the LORD, "that I am God."<br><strong>Isaiah 43:12</strong>',
            'explanation'    => 'There is nothing more persuasive than an irrefutable testimony of God’s existence and power. Saying “I was blind but now I see” strengthens the listener’s faith that God is real and active. Fathers guide Sons to balance testimony, focusing on God’s redeeming power rather than past misery.'
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview personal-testimony-module"
             data-module="PersonalTestimony"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <style>
                .testimony-wrapper {
                    max-width: 1000px;
                    margin: 0 auto;
                    font-family: Arial, sans-serif;
                }

                .testimony-instruction {
                    text-align: center;
                    font-weight: bold;
                    color: #555;
                    margin-bottom: 15px;
                }

                .testimony-container {
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    overflow: hidden;
                    background: #fff;
                }

                .testimony-header {
                    display: flex;
                    background-color: #074a77;
                    color: #fff;
                    font-weight: bold;
                    text-align: center;
                }

                .testimony-header div {
                    padding: 15px;
                    flex: 1;
                    border-right: 1px solid #fff;
                }

                .testimony-header div:last-child {
                    border-right: none;
                }

                .testimony-content {
                    display: flex;
                }

                .testimony-col {
                    padding: 15px;
                    box-sizing: border-box;
                    background: #fff;
                    color: #074a77;
                    border-right: 1px solid #ccc;
                    flex: 1;
                }

                .testimony-col:last-child {
                    border-right: none;
                }

                .score-input {
                    width: 80px;
                    height: 40px;
                    font-size: 1.2em;
                    text-align: center;
                    border: 1px solid #999;
                    border-radius: 5px;
                    margin: 20px auto 10px;
                    display: block;
                }

                .score-label {
                    text-align: center;
                    margin-top: 8px;
                }

                .section-title {
                    font-weight: bold;
                    color: #074a77;
                    text-align: left;
                }
            </style>

            <div class="testimony-wrapper">
                <!-- Instruction outside the module box -->
                <div class="testimony-instruction">
                    Give yourself a score on a scale from 1 (I’m unable) to 10 (I’m fully capable).
                </div>

                <!-- Main bordered container -->
                <div class="testimony-container">
                    <!-- Headers -->
                    <div class="testimony-header">
                        <div>HOW WELL DO I...</div>
                        <div>RELATED VERSES</div>
                        <div>EXPLANATION</div>
                    </div>

                    <!-- Content -->
                    <div class="testimony-content">
                        <div class="testimony-col">
                            <div class="section-title"><?php echo esc($this->settings['sectionTitle']); ?></div>
                            <input type="number" min="1" max="10" class="score-input">
                            <div class="score-label"><?php echo esc($this->settings['scoreLabel']); ?></div>
                        </div>

                        <div class="testimony-col">
                            <p style="font-style: italic;"><?php echo $this->settings['verseText']; ?></p>
                        </div>

                        <div class="testimony-col">
                            <p><?php echo esc($this->settings['explanation']); ?></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="PersonalTestimony">' 
            . esc($this->settings['buttonName']) . 
            '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="sectionTitle">Section Title:</label>
            <input type="text" id="sectionTitle" data-update="sectionTitle" value="<?php echo esc($this->settings['sectionTitle']); ?>">
        </div>

        <div class="form-group">
            <label for="scoreLabel">Score Label:</label>
            <input type="text" id="scoreLabel" data-update="scoreLabel" value="<?php echo esc($this->settings['scoreLabel']); ?>">
        </div>

        <div class="form-group">
            <label for="verseText">Verse Text:</label>
            <textarea id="verseText" data-update="verseText" rows="5"><?php echo esc($this->settings['verseText']); ?></textarea>
        </div>

        <div class="form-group">
            <label for="explanation">Explanation Text:</label>
            <textarea id="explanation" data-update="explanation" rows="5"><?php echo esc($this->settings['explanation']); ?></textarea>
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
