<?php
// modules/SelfScoreTextBox.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class SelfScoreTextBox {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('selfScoreTextBox_');
        $this->settings = array_merge([
            'buttonName'         => 'Self Score / Text Box',
            'spiritualQuality'   => 'Devotion to the Fatherhood/Sonship Doctrine',
            'matureViewpoint'    => 'Knows that as fathers we “go and prepare a place” for sons, and as sons we wait for phased release into our destiny by our father',
            'immatureViewpoint'  => 'Retains an Orphan Spirit; rejects fatherhood as authoritarian; feels abandoned & rejected; self-referential; autonomous; uncoachable',
            'relatedVerse'       => 'John 14:2-3',
            'scoreLabel'         => 'SCORE',
            'textBoxLabel'       => 'How I could improve this spiritual quality:',
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        
        <div class="module-preview self-score-textbox-module"
             data-module="SelfScoreTextBox"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <style>
                .self-score-container {
                    max-width: 1100px;
                    margin: 0 auto;
                    font-family: Arial, sans-serif;
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    overflow: hidden;
                    background: #fff;
                }
                .self-score-header {
                    background: #074a77;
                    color: #fff;
                    font-weight: bold;
                    display: flex;
                    text-align: center;
                }
                .self-score-header div {
                    flex: 1;
                    padding: 12px;
                    border-right: 1px solid #fff;
                }
                .self-score-header div:last-child {
                    border-right: none;
                }
                .self-score-row {
                    display: flex;
                    border-top: 1px solid #ccc;
                    color: #074a77;
                }
                .self-score-cell {
                    flex: 1;
                    padding: 15px;
                    border-right: 1px solid #ccc;
                    vertical-align: top;
                }
                .self-score-cell:last-child {
                    border-right: none;
                    text-align: center;
                }
                .bold-text {
                    font-weight: bold;
                }
                .score-input {
                    width: 80px;
                    height: 40px;
                    text-align: center;
                    border: 1px solid #999;
                    border-radius: 5px;
                    font-size: 1.2em;
                    margin-top: 10px;
                }
                .score-label {
                    margin-top: 8px;
                    color: #074a77;
                }
                .improve-section {
                    padding: 15px;
                    color: #074a77;
                }
                .improve-label {
                    font-weight: bold;
                    margin-bottom: 8px;
                    display: block;
                }
                .improve-textarea {
                    width: 100%;
                    height: 120px;
                    border-radius: 8px;
                    border: 1px solid #999;
                    padding: 10px;
                    resize: vertical;
                }
            </style>
            
            <div style="max-width: 1100px; margin: 0 auto; font-family: Arial, sans-serif; color: #444; font-size: 16px; text-align: center; font-weight: bold; padding: 15px;">
    Give yourself a score from 1 to 10 depending on how consistently you demonstrate "the mature viewpoint".<br>
    For your reference, we have included "the immature/soulish viewpoint" as well.
</div>

            
            
            <div class="self-score-container">
                <!-- Header -->
                <div class="self-score-header">
                    <div>SPIRITUAL QUALITY</div>
                    <div>THE MATURE VIEWPOINT</div>
                    <div>THE IMMATURE OR SOULISH VIEWPOINT</div>
                    <div>RELATED VERSE</div>
                    <div>MY SCORE</div>
                </div>

                <!-- Row Content -->
                <div class="self-score-row">
                    <div class="self-score-cell bold-text"><?php echo esc($this->settings['spiritualQuality']); ?></div>
                    <div class="self-score-cell"><?php echo esc($this->settings['matureViewpoint']); ?></div>
                    <div class="self-score-cell"><?php echo esc($this->settings['immatureViewpoint']); ?></div>
                    <div class="self-score-cell bold-text"><?php echo esc($this->settings['relatedVerse']); ?></div>
                    <div class="self-score-cell">
                        <input type="number" min="1" max="10" class="score-input">
                        <div class="score-label"><?php echo esc($this->settings['scoreLabel']); ?></div>
                    </div>
                </div>

                <!-- Improvement Textbox -->
                <div class="improve-section">
                    <span class="improve-label"><?php echo esc($this->settings['textBoxLabel']); ?></span>
                    <textarea class="improve-textarea"></textarea>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="SelfScoreTextBox">'
             . esc($this->settings['buttonName']) . '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        
        
        
        
        <div class="form-group">
            <label for="spiritualQuality">Spiritual Quality:</label>
            <input type="text" id="spiritualQuality" data-update="spiritualQuality"
                   value="<?php echo esc($this->settings['spiritualQuality']); ?>">
        </div>

        <div class="form-group">
            <label for="matureViewpoint">Mature Viewpoint:</label>
            <textarea id="matureViewpoint" data-update="matureViewpoint" rows="4"><?php echo esc($this->settings['matureViewpoint']); ?></textarea>
        </div>

        <div class="form-group">
            <label for="immatureViewpoint">Immature or Soulish Viewpoint:</label>
            <textarea id="immatureViewpoint" data-update="immatureViewpoint" rows="4"><?php echo esc($this->settings['immatureViewpoint']); ?></textarea>
        </div>

        <div class="form-group">
            <label for="relatedVerse">Related Verse:</label>
            <input type="text" id="relatedVerse" data-update="relatedVerse"
                   value="<?php echo esc($this->settings['relatedVerse']); ?>">
        </div>

        <div class="form-group">
            <label for="textBoxLabel">Text Box Prompt:</label>
            <input type="text" id="textBoxLabel" data-update="textBoxLabel"
                   value="<?php echo esc($this->settings['textBoxLabel']); ?>">
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
