<?php
// modules/TitlePage.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

// Helper functions if not already defined
if (!function_exists('base_url')) {
    function base_url($path = '') {
        return "https://main.winslowapps.com/" . ltrim($path, '/');
    }
}

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class TitlePage {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('titlePage_');
        // ✅ Default settings + buttonName for sidebar
        $this->settings = array_merge([
            'buttonName'    => 'Title Page',
            'title'         => 'Enter Title Here',
            'subtitle'      => 'Enter Subtitle Here',
            'author'        => 'By Author Name',
            'topLogo'       => base_url('logo-placeholder-image.png'),
            'topLogoWidth'  => 15,
        ], $settings);
    }

public function render() {
    ob_start(); ?>
    <div class="title-page-container title-page-module" 
         data-module="TitlePage" 
         data-module-id="<?php echo esc($this->instanceId); ?>"
         style="min-height: 80vh; position: relative; padding-bottom: 150px;">  <!-- ✅ Adjusted height and padding -->

        <div class="title-content">

            <!-- Top Logo -->
            <div class="top-logo" style="
                position: absolute;
                top: 5%;
                left: 50%;
                transform: translateX(-50%);
                width: <?php echo esc($this->settings['topLogoWidth']); ?>%;
            ">
                <img src="<?php echo esc($this->settings['topLogo']); ?>" alt="Top Logo" style="width: 100%; height: auto;">
            </div>

            <!-- Title & Subtitle Section -->
            <div class="title-section" style="
                position: absolute;
                top: 30%;
                left: 50%;
                transform: translateX(-50%);
                width: 70%;
                text-align: center;
            ">
                <div class="title-line"></div>
                <h1><?php echo esc($this->settings['title']); ?></h1>
                <h2><?php echo esc($this->settings['subtitle']); ?></h2>
                <div class="title-line"></div>
                <h3><?php echo esc($this->settings['author']); ?></h3>
            </div>

            <!-- ✅ Bottom-section REMOVED. PageBreak handles it now. -->

        </div>
    </div>
    <?php
    return ob_get_clean();
}

    // ✅ Sidebar menu displays the correct label
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="TitlePage">'
             . esc($this->settings['buttonName']) . 
             '</button>';
    }
}
?>
