console.log("LIVE SETTINGS PANEL LOADED from", window.location.href);

// TinyMCE Modal Logic (unchanged)
function openTinyMCEModal(existingContent, callback) {
    const modal = document.getElementById('tinymceModal');
    const editorArea = document.getElementById('tinymceEditor');
    const saveBtn = document.getElementById('saveTinyContent');
    const cancelBtn = document.getElementById('cancelTinyContent');

    // Check if TinyMCE editor is already initialized
    if (tinymce.get('tinymceEditor')) {
        tinymce.get('tinymceEditor').setContent(existingContent);
    } else {
        editorArea.value = existingContent;
        tinymce.init({
            selector: '#tinymceEditor',
            menubar: false,
            plugins: 'lists link code',
            toolbar: 'undo redo | styleselect | bold italic underline | alignleft aligncenter alignright | bullist numlist | code',
            height: 300
        });
    }

    // Show the modal
    modal.style.display = 'flex';

    // Save button functionality
    saveBtn.onclick = () => {
        const updatedContent = tinymce.get('tinymceEditor').getContent();
        modal.style.display = 'none';
        callback(updatedContent); // Call the callback with the updated content
    };

    // Cancel button functionality
    cancelBtn.onclick = () => {
        modal.style.display = 'none'; // Close the modal on cancel
    };
}

// ✅ Unified Dynamic Settings Loader with Dynamic PageBreak Numbering
window.loadModuleSettings = async function (module) {
    console.log("Loading Module Settings:", module);
    const settingsPanel = document.getElementById('settings-pane');
    if (!settingsPanel) {
        console.error("Settings panel (#settings-pane) not found.");
        return;
    }

    const moduleType = module.getAttribute('data-module');
    console.log("Module Type Detected:", moduleType);

    // ✅ Dynamic Page Numbering for PageBreak modules
    if (moduleType === 'PageBreak' && moduleSettingsMarkup && moduleSettingsMarkup[moduleType]) {
        const pageBreaks = Array.from(document.querySelectorAll('.canvas .page-break-module'));
        const pageNumber = pageBreaks.indexOf(module) + 1;
        console.log("Dynamic PageBreak Number:", pageNumber);

        // Replace any existing hardcoded Page Break # with the actual number
        let settingsHtml = moduleSettingsMarkup[moduleType];
        settingsHtml = settingsHtml.replace(/Page Break #\d+/g, `Page Break #${pageNumber}`);

        settingsPanel.innerHTML = settingsHtml;
        return;
    }

    // ✅ Default PHP-rendered settings if available
    if (moduleSettingsMarkup && moduleSettingsMarkup[moduleType]) {
        console.log("Found PHP Settings for:", moduleType);
        settingsPanel.innerHTML = moduleSettingsMarkup[moduleType];
        return;
    }

    // ✅ Fallback to dynamic JS-driven settings for modules like Likert, MultiParagraph
    settingsPanel.innerHTML = '<h2>Module Settings</h2>';

    let requestedSettings = [];
    try {
        requestedSettings = JSON.parse(module.getAttribute('data-settings-config') || '[]');
        console.log("Requested Dynamic Settings:", requestedSettings);
    } catch (err) {
        console.error("Failed to parse settings config:", err);
    }

    const tbody = module.querySelector('tbody');

    // Dynamic settings processing loop
    for (const settingKey of requestedSettings) {
        console.log("Processing setting:", settingKey);

        if (settingKey === "fonts") {
            const fontsModule = await import(`./settings/fonts.js?v=${Date.now()}`);
            fontsModule?.default?.render(module, settingsPanel);
        } else if (settingKey === "titleText") {
            const wrapper = document.createElement('div');
            wrapper.innerHTML = `<label>Title Text:</label><input type="text" placeholder="Enter title text">`;
            settingsPanel.appendChild(wrapper);
            const input = wrapper.querySelector('input');
            const h1 = module.querySelector('h1');
            if (h1 && h1.textContent.trim() !== "Sample Page Title") input.value = h1.textContent.trim();
            input.addEventListener('input', () => {
                if (h1) h1.textContent = input.value || "Sample Page Title";
                module.setAttribute('data-title-text', input.value);
            });
            const saved = module.getAttribute('data-title-text');
            if (saved) {
                input.value = saved;
                if (h1) h1.textContent = saved;
            }
        } else if (settingKey === "multiParagraph") {
            const multiParagraphModule = await import(`./settings/multiParagraph.js?v=${Date.now()}`);
            multiParagraphModule?.default?.render(module, settingsPanel);
        } else if (settingKey === "mainHeading") {
            const wrapper = document.createElement('div');
            wrapper.innerHTML = `<label>Main Heading:</label><input type="text" placeholder="Enter main heading">`;
            settingsPanel.appendChild(wrapper);
            const input = wrapper.querySelector('input');
            const headingEl = module.querySelector('.table-main-heading');
            if (headingEl) input.value = headingEl.textContent.trim();
            input.addEventListener('input', () => headingEl.textContent = input.value);
        } else if (settingKey === "statementColumn") {
            const wrapper = document.createElement('div');
            wrapper.innerHTML = `<label>Left Column Header:</label><input type="text" placeholder="Enter left column header">`;
            settingsPanel.appendChild(wrapper);
            const input = wrapper.querySelector('input');
            const col = module.querySelector('thead th:first-child');
            if (col) input.value = col.textContent.trim();
            input.addEventListener('input', () => col.textContent = input.value);
        } else if (settingKey === "scaleColumn") {
            const wrapper = document.createElement('div');
            wrapper.innerHTML = `<label>Right Column Header:</label><input type="text" placeholder="Enter right column header">`;
            settingsPanel.appendChild(wrapper);
            const input = wrapper.querySelector('input');
            const col = module.querySelector('thead th:last-child');
            if (col) input.value = col.textContent.trim();
            input.addEventListener('input', () => col.textContent = input.value);
        } else if (settingKey === "statements") {
            const dynamicWrapper = document.createElement('div');
            dynamicWrapper.classList.add('dynamic-statements-wrapper');
            settingsPanel.appendChild(dynamicWrapper);

            const renderStatements = () => {
                dynamicWrapper.innerHTML = '';
                const sectionLabel = document.createElement('label');
                sectionLabel.textContent = 'Scales / Statements:';
                dynamicWrapper.appendChild(sectionLabel);

                const rows = module.querySelectorAll('tbody tr');
                rows.forEach((row, index) => {
                    const labelEl = row.querySelector('.statement-label');
                    const rowDiv = document.createElement('div');
                    rowDiv.classList.add('statement-row');
                    rowDiv.innerHTML = `<input type="text" value="${labelEl.textContent.trim()}">
                                        <button class="remove-btn">−</button>`;
                    const input = rowDiv.querySelector('input');
                    const removeBtn = rowDiv.querySelector('button');
                    input.addEventListener('input', () => labelEl.textContent = input.value);
                    removeBtn.addEventListener('click', () => {
                        row.remove();
                        renderStatements();
                    });
                    dynamicWrapper.appendChild(rowDiv);
                });

                const addBtn = document.createElement('button');
                addBtn.textContent = '+ Add Scale';
                addBtn.classList.add('add-btn');
                addBtn.onclick = () => {
                    const newIndex = module.querySelectorAll('tbody tr').length;
                    const newRow = document.createElement('tr');
                    newRow.innerHTML = `
                        <td class="statement-label">New Statement ${newIndex + 1}</td>
                        <td>
                            <div class="likert-row">
                                ${[0, 1, 2, 3, 4, 5].map(val => `
                                    <label class="likert-cell">
                                        <div class="likert-value">${val}</div>
                                        <div class="likert-radio">
                                            <input type="radio" name="likert_${module.dataset.moduleId}_row${newIndex}" value="${val}">
                                        </div>
                                    </label>
                                `).join('')}
                            </div>
                        </td>`;
                    tbody.appendChild(newRow);
                    renderStatements();
                };
                dynamicWrapper.appendChild(addBtn);
            };
            renderStatements();
        } else {
            console.warn("No handler found for setting:", settingKey);
        }
    }
};

// ✅ Reusable Image Upload / Select Modal
function openImageUploadModal(callback) {
    console.log("Launching image upload modal...");

    // Create the modal if it doesn't exist
    let modal = document.getElementById('imageUploadModal');
    if (!modal) {
        modal = document.createElement('div');
        modal.id = 'imageUploadModal';
        modal.style.position = 'fixed';
        modal.style.top = '50%';
        modal.style.left = '50%';
        modal.style.transform = 'translate(-50%, -50%)';
        modal.style.background = '#fff';
        modal.style.padding = '20px';
        modal.style.border = '1px solid #ccc';
        modal.style.zIndex = '10000';
        modal.style.maxHeight = '80vh';
        modal.style.overflowY = 'auto';
        modal.innerHTML = `
            <h3>Select or Upload Image</h3>
            <input type="file" id="imageFileInput"><br><br>
            <div id="existingImages" style="display: flex; flex-wrap: wrap; gap: 10px;"></div>
            <button onclick="document.getElementById('imageUploadModal').remove()">Close</button>
        `;
        document.body.appendChild(modal);
    }

    // ✅ Load existing images from the uploads directory
    fetch('/uploads/index.json') // You'll need to generate this JSON or scan uploads server-side
        .then(response => response.json())
        .then(images => {
            const container = modal.querySelector('#existingImages');
            container.innerHTML = '';
            images.forEach(img => {
                const imgEl = document.createElement('img');
                imgEl.src = '/uploads/' + img;
                imgEl.style.width = '100px';
                imgEl.style.cursor = 'pointer';
                imgEl.onclick = () => {
                    callback('/uploads/' + img);  // Pass the selected image URL to the callback
                    modal.remove();
                };
                container.appendChild(imgEl);
            });
        });

    // ✅ Handle new file upload
    modal.querySelector('#imageFileInput').onchange = function () {
        const file = this.files[0];
        const formData = new FormData();
        formData.append('image', file);

        fetch('/image-upload-handler', {
            method: 'POST',
            body: formData
        })
        .then(res => res.json())
        .then(data => {
            if (data.success) {
                callback(data.url);  // Pass the uploaded file URL to the callback
                modal.remove();
            } else {
                alert('Upload failed.');
            }
        });
    };
}
