// ✅ paragraphTextAndScripture.js

console.log("🧩 paragraphTextAndScripture.js loaded.");

function initParagraphScriptureModule() {
  console.log("📡 Watching for ParagraphTextAndScripture settings panel injection...");

  const MAX_ATTEMPTS = 20;
  let attempts = 0;

  const interval = setInterval(() => {
    const settingsWrapper = document.querySelector('.module-settings[data-module="ParagraphTextAndScripture"]');
    if (!settingsWrapper) {
      console.warn(`❌ Settings panel not yet found. Retrying... (attempt ${attempts + 1})`);
      attempts++;
      if (attempts >= MAX_ATTEMPTS) {
        clearInterval(interval);
        console.error("⏱️ Gave up after too many attempts.");
      }
      return;
    }

    clearInterval(interval);
    console.log("✅ Found settings panel for ParagraphTextAndScripture");

    const instanceId = settingsWrapper.id.replace('paragraphTextAndScriptureSettings_', '');
    console.log("🧪 Extracted instanceId:", instanceId);

    const previewModule = document.querySelector(`[data-module-id="${instanceId}"]`);
    if (previewModule) {
      console.log("✅ Found matching preview module in DOM for", instanceId);
    } else {
      console.warn("❌ No matching preview module found for instanceId:", instanceId);
    }

    const inputs = settingsWrapper.querySelectorAll('[data-setting]');
    console.log(`🎯 Found ${inputs.length} data-setting inputs`);

    if (inputs.length === 0) {
      console.warn("⚠️ No data-setting inputs found in settings panel.");
    }

    inputs.forEach(input => {
      const setting = input.getAttribute('data-setting');
      console.log(`🔍 Attaching listeners for [${setting}]`);

      input.addEventListener('focus', () => {
        console.log(`👀 Focused on [${setting}]`);
      });

      input.addEventListener('input', () => {
        console.log(`📝 Input for [${setting}]:`, input.value);
        const currentSettings = getModuleSettings(instanceId);
        currentSettings[setting] = input.value;
        updateModuleSettings(instanceId, currentSettings);
      });

      input.addEventListener('change', () => {
        console.log(`📤 Change on [${setting}]:`, input.value);
      });
    });

    const contentTypeSelect = settingsWrapper.querySelector('[data-setting="contentType"]');
    const scriptureBlock = settingsWrapper.querySelector('.scripture-settings');
    if (contentTypeSelect && scriptureBlock) {
      contentTypeSelect.addEventListener('change', () => {
        scriptureBlock.style.display = contentTypeSelect.value === 'scripture' ? '' : 'none';
        console.log(`📖 Toggled scripture visibility: ${contentTypeSelect.value}`);
      });
    } else {
      console.warn("⚠️ Missing contentType dropdown or scripture-settings div.");
    }
  }, 300);
}

document.addEventListener('DOMContentLoaded', initParagraphScriptureModule);
