console.log("🧪 WS App Maker JS Loaded");

document.addEventListener('DOMContentLoaded', function () {
  const canvas = document.getElementById('canvas');
  const moduleButtons = document.querySelectorAll('.module-selector-btn');

  window.moduleSettings = {};

  moduleButtons.forEach(button => {
    button.addEventListener('click', () => {
      const moduleType = button.getAttribute('data-module');
      console.log("➕ Adding module:", moduleType);

      if (!window.moduleMarkup || !window.moduleMarkup[moduleType]) {
        console.error("❌ No module markup found for:", moduleType);
        return;
      }

      const temp = document.createElement('div');
      temp.innerHTML = window.moduleMarkup[moduleType].trim();
      const newModule = temp.firstElementChild;
      const instanceId = newModule.getAttribute('data-module-id');

      canvas.appendChild(newModule);
      newModule.classList.add('selected');

      // Initial settings
      window.moduleSettings[instanceId] = {};

      // Load settings panel
      loadSettingsPanel(moduleType, instanceId);
    });
  });
});

function loadSettingsPanel(moduleType, instanceId) {
  const settingsContent = document.getElementById('settings-content');
  if (!window.moduleSettingsMarkup || !window.moduleSettingsMarkup[moduleType]) {
    console.warn("⚠️ No settings markup found for", moduleType);
    return;
  }

  const html = window.moduleSettingsMarkup[moduleType];
  settingsContent.innerHTML = html;

  console.log("🧰 Injected settings panel for", moduleType);

  // After injecting, init listeners
  initV2Settings(instanceId);
}

function initV2Settings(instanceId) {
  const settingsPane = document.querySelector(`[data-instance-id="${instanceId}"]`);
  if (!settingsPane) {
    console.error("❌ Settings panel not found for instance:", instanceId);
    return;
  }

  const inputs = settingsPane.querySelectorAll('[data-setting]');
  console.log(`🎯 Found ${inputs.length} inputs in settings panel`);

  inputs.forEach(input => {
    const key = input.getAttribute('data-setting');

    input.addEventListener('input', () => {
      const value = input.value;
      console.log(`📝 [${instanceId}] ${key} =`, value);
      window.moduleSettings[instanceId][key] = value;

      updateModulePreview(instanceId);
    });
  });
}

function updateModulePreview(instanceId) {
  const settings = window.moduleSettings[instanceId];
  const moduleEl = document.querySelector(`[data-module-id="${instanceId}"]`);
  const moduleType = moduleEl?.getAttribute('data-module');

  if (!moduleEl || !moduleType) {
    console.error("❌ Missing module element or type for", instanceId);
    return;
  }

  console.log("📡 Sending AJAX update for", instanceId, settings);

  fetch('/ws-app-maker/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ moduleType, instanceId, settings })
  })
    .then(res => res.json())
    .then(data => {
      if (data.error) return console.error("❌ Server error:", data.error);

      const wrapper = document.createElement('div');
      wrapper.innerHTML = data.preview.trim();
      const newModule = wrapper.firstElementChild;

      moduleEl.replaceWith(newModule);

      document.getElementById('settings-content').innerHTML = data.settings;
      console.log("✅ Module and settings updated");
    })
    .catch(err => {
      console.error("🔥 AJAX error:", err);
    });
}
