console.log("✅ Image Uploader Loaded");

// Opens the image upload modal
window.openImageUploadModal = function (callback) {
    const modal = document.createElement('div');
    modal.className = 'image-upload-modal';
    modal.style = `
        position: fixed; top: 0; left: 0; right: 0; bottom: 0;
        background: rgba(0,0,0,0.7); display: flex;
        align-items: center; justify-content: center; z-index: 9999;
    `;

    modal.innerHTML = `
        <div style="background:#fff; padding:20px; width:600px; max-height:80vh; overflow-y:auto; border-radius:8px; position:relative;">
            <h2 style="margin-bottom:10px;">Upload or Select Image</h2>
            <input type="file" id="imageFileInput"><br><br>
            <button id="uploadImageBtn" style="margin-bottom:15px;">Upload</button>
            <div id="uploadResult"></div>
            <hr>
            <h3>Browse Existing Images</h3>
            <div id="imageList" style="display:flex; flex-wrap:wrap; gap:10px;"></div>
            <button style="margin-top:15px;" id="closeUploadModal">Close</button>
        </div>
    `;
    document.body.appendChild(modal);

    // Close action
    modal.querySelector('#closeUploadModal').onclick = () => modal.remove();

    // Upload new image
    modal.querySelector('#uploadImageBtn').onclick = async () => {
        const fileInput = modal.querySelector('#imageFileInput');
        if (!fileInput.files[0]) {
            alert('Please select an image');
            return;
        }

        const formData = new FormData();
        formData.append('file', fileInput.files[0]);

        const response = await fetch('/image-upload', {
            method: 'POST',
            body: formData
        });
        const result = await response.json();
        if (result.success) {
            modal.querySelector('#uploadResult').innerHTML = `<p style="color:green;">Uploaded: <a href="${result.filePath}" target="_blank">${result.fileName}</a></p>`;
            loadImageList(modal, callback);
        } else {
            modal.querySelector('#uploadResult').innerHTML = `<p style="color:red;">${result.message}</p>`;
        }
    };

    // Load and display existing images
    loadImageList(modal, callback);
};

// Fetch and render the image list
async function loadImageList(modal, callback) {
    const listContainer = modal.querySelector('#imageList');
    listContainer.innerHTML = 'Loading...';

    const res = await fetch('/image-list');
    const data = await res.json();

    if (data.success) {
        listContainer.innerHTML = '';
        data.files.forEach(file => {
            const img = document.createElement('img');
            img.src = file.url;
            img.alt = file.name;
            img.style = 'width:100px; height:100px; object-fit:cover; cursor:pointer; border:1px solid #ccc;';
            img.onclick = () => {
                callback(file.url);
                modal.remove();
            };
            listContainer.appendChild(img);
        });

        if (data.files.length === 0) {
            listContainer.innerHTML = '<p>No images uploaded yet.</p>';
        }
    } else {
        listContainer.innerHTML = '<p>Error loading images.</p>';
    }
}
