// ✅ paragraphTextAndScripture.js
document.addEventListener('DOMContentLoaded', () => {
  console.log("🧩 paragraphTextAndScripture.js loaded.");
  const settingsContainer = document.getElementById('settings-content');

  if (!settingsContainer) {
    console.warn("⚠️ settings-content panel not found.");
    return;
  }

  // 🧪 Watch for settings panel injection
  console.log("📡 Watching for ParagraphTextAndScripture settings panel injection...");

  const observer = new MutationObserver((mutationsList) => {
    for (const mutation of mutationsList) {
      if (mutation.type === 'childList') {
        const wrapper = settingsContainer.querySelector('[data-module="ParagraphTextAndScripture"]');
        if (wrapper) {
          console.log("✅ ParagraphTextAndScripture settings panel detected.");

          wrapper.querySelectorAll('[data-setting]').forEach(input => {
            const setting = input.getAttribute('data-setting');

            input.addEventListener('focus', () => {
              console.log(`🟢 Input focused: [${setting}]`);
            });

            input.addEventListener('blur', () => {
              console.log(`🔴 Input blurred: [${setting}]`);
            });

            input.addEventListener('input', () => {
              const instanceId = wrapper.id?.replace('paragraphTextAndScriptureSettings_', '') || '';
              const value = input.value;

              console.log(`📝 Setting updated: ${setting} = ${value}`);

              const currentSettings = getModuleSettings(instanceId);
              currentSettings[setting] = value;
              updateModuleSettings(instanceId, currentSettings);
            });
          });

          observer.disconnect(); // Stop watching after attaching once
          break;
        }
      }
    }
  });

  observer.observe(settingsContainer, { childList: true, subtree: true });
});
