<?php
// spacing-settings.php
// Optionally, you can define default spacing values if not provided.
$defaultSpacing = [
    'margin' => [
        'top'    => '10',
        'right'  => 'auto',
        'bottom' => '10',
        'left'   => 'auto'
    ],
    'padding' => [
        'top'    => '10',
        'right'  => '10',
        'bottom' => '10',
        'left'   => '10'
    ]
];

// If you pass in a variable $spacing from your module settings, use it;
// otherwise, use the default values.
if (!isset($spacing)) {
    $spacing = $defaultSpacing;
}
?>

<div class="spacing-settings">
  <h3>Spacing Settings</h3>
  
  <!-- Margin Settings -->
  <div class="spacing-section">
    <h4>Margin</h4>
    <div class="spacing-inputs">
      <div class="spacing-item">
        <label for="marginTop">Top</label>
        <input type="number" id="marginTop" value="<?= htmlspecialchars($spacing['margin']['top']); ?>" min="0">
      </div>
      <div class="spacing-item">
        <label for="marginRight">Right</label>
        <input type="text" id="marginRight" value="<?= htmlspecialchars($spacing['margin']['right']); ?>" placeholder="auto">
      </div>
      <div class="spacing-item">
        <label for="marginBottom">Bottom</label>
        <input type="number" id="marginBottom" value="<?= htmlspecialchars($spacing['margin']['bottom']); ?>" min="0">
      </div>
      <div class="spacing-item">
        <label for="marginLeft">Left</label>
        <input type="text" id="marginLeft" value="<?= htmlspecialchars($spacing['margin']['left']); ?>" placeholder="auto">
      </div>
    </div>
  </div>
  
  <!-- Padding Settings -->
  <div class="spacing-section">
    <h4>Padding</h4>
    <div class="spacing-inputs">
      <div class="spacing-item">
        <label for="paddingTop">Top</label>
        <input type="number" id="paddingTop" value="<?= htmlspecialchars($spacing['padding']['top']); ?>" min="0">
      </div>
      <div class="spacing-item">
        <label for="paddingRight">Right</label>
        <input type="number" id="paddingRight" value="<?= htmlspecialchars($spacing['padding']['right']); ?>" min="0">
      </div>
      <div class="spacing-item">
        <label for="paddingBottom">Bottom</label>
        <input type="number" id="paddingBottom" value="<?= htmlspecialchars($spacing['padding']['bottom']); ?>" min="0">
      </div>
      <div class="spacing-item">
        <label for="paddingLeft">Left</label>
        <input type="number" id="paddingLeft" value="<?= htmlspecialchars($spacing['padding']['left']); ?>" min="0">
      </div>
    </div>
  </div>
</div>

<style>
  .spacing-settings {
    font-family: 'Open Sans', sans-serif;
    padding: 20px;
    background: #f9f9f9;
    border: 1px solid #ddd;
    border-radius: 8px;
    max-width: 400px;
    margin: 20px auto;
  }
  .spacing-settings h3 {
    margin-top: 0;
    font-size: 1.5em;
    color: #2c3e8f;
    text-align: center;
  }
  .spacing-section {
    margin-bottom: 20px;
  }
  .spacing-section h4 {
    margin-bottom: 10px;
    font-size: 1.2em;
    color: #2c3e8f;
    border-bottom: 1px solid #ddd;
    padding-bottom: 5px;
  }
  .spacing-inputs {
    display: grid;
    grid-template-columns: 1fr 1fr;
    gap: 10px;
  }
  .spacing-item {
    display: flex;
    flex-direction: column;
  }
  .spacing-item label {
    font-size: 0.9em;
    margin-bottom: 3px;
    color: #555;
  }
  .spacing-item input {
    padding: 5px;
    border: 1px solid #ccc;
    border-radius: 4px;
    font-size: 0.9em;
  }
</style>

<script>
  // This function reads the spacing input values and updates the preview element live.
  function updateSpacingPreview() {
    var settings = {
      margin: {
        top: document.getElementById('marginTop').value,
        right: document.getElementById('marginRight').value,
        bottom: document.getElementById('marginBottom').value,
        left: document.getElementById('marginLeft').value
      },
      padding: {
        top: document.getElementById('paddingTop').value,
        right: document.getElementById('paddingRight').value,
        bottom: document.getElementById('paddingBottom').value,
        left: document.getElementById('paddingLeft').value
      }
    };
    console.log("Live spacing settings:", settings);
    
    // Find the currently selected module in the canvas.
    var selectedModule = document.querySelector('.module-preview.selected');
    if (selectedModule) {
      // Update margins on the module container.
      selectedModule.style.marginTop = settings.margin.top + "px";
      selectedModule.style.marginRight = settings.margin.right;
      selectedModule.style.marginBottom = settings.margin.bottom + "px";
      selectedModule.style.marginLeft = settings.margin.left;
      
      // Update paddings on the inner .text-container element.
      var textContainer = selectedModule.querySelector('.text-container');
      if (textContainer) {
        textContainer.style.paddingTop = settings.padding.top + "px";
        textContainer.style.paddingRight = settings.padding.right + "px";
        textContainer.style.paddingBottom = settings.padding.bottom + "px";
        textContainer.style.paddingLeft = settings.padding.left + "px";
        console.log("Live preview updated with new spacing settings.");
      } else {
        console.warn("No text container found in the selected module.");
      }
    } else {
      console.warn("No module is selected; cannot update preview.");
    }
  }

  // Attach event listeners for live updates on spacing inputs.
  document.addEventListener('DOMContentLoaded', function() {
    var inputs = document.querySelectorAll('.spacing-settings input');
    inputs.forEach(function(input) {
      input.addEventListener('input', updateSpacingPreview);
    });
  });
</script>
