// tinymce-settings.js

// Function to initialize tinymce on a given selector
function initializeTinymce(selector, config = {}) {
    const defaultConfig = {
        selector: selector,
        plugins: 'lists link image code',
        toolbar: 'undo redo | bold italic | alignleft aligncenter alignright | code',
        menubar: false,
        setup: function(editor) {
            // You can add custom setup code here
            editor.on('init', function() {
                console.log('TinyMCE editor initialized on ' + selector);
            });
        }
    };

    tinymce.init({ ...defaultConfig, ...config });
}

// Function to open a modal with a TinyMCE editor
function openTinyMCEModal(initialContent, callback) {
    // Create a modal container if not already present
    let modal = document.getElementById('tinymceModal');
    if (!modal) {
        modal = document.createElement('div');
        modal.id = 'tinymceModal';
        modal.style.position = 'fixed';
        modal.style.top = '50%';
        modal.style.left = '50%';
        modal.style.transform = 'translate(-50%, -50%)';
        modal.style.zIndex = 1000;
        modal.style.backgroundColor = '#fff';
        modal.style.padding = '20px';
        modal.style.border = '1px solid #ccc';
        modal.innerHTML = `
            <textarea id="tinymceEditor"></textarea>
            <button id="saveTinymceContent">Save</button>
            <button id="cancelTinymceContent">Cancel</button>
        `;
        document.body.appendChild(modal);
    }

    // Set the textarea value to the initial content
    document.getElementById('tinymceEditor').value = initialContent;

    // Initialize TinyMCE on the modal textarea
    initializeTinymce('#tinymceEditor');

    // Setup event listeners for Save and Cancel
    document.getElementById('saveTinymceContent').onclick = function() {
        const updatedContent = tinymce.get('tinymceEditor').getContent();
        // Clean up editor instance
        tinymce.get('tinymceEditor').remove();
        modal.style.display = 'none';
        callback(updatedContent);
    };

    document.getElementById('cancelTinymceContent').onclick = function() {
        // Remove editor instance and hide modal
        if(tinymce.get('tinymceEditor')){
            tinymce.get('tinymceEditor').remove();
        }
        modal.style.display = 'none';
    };

    modal.style.display = 'block';
}
